@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2005-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
@@ -21,24 +21,22 @@
 **
 ****************************************************************************/
 
-#include <QtDesigner/QDesignerContainerExtension>
-#include <QtDesigner/QDesignerCustomWidgetInterface>
+#ifndef CUSTOMWIDGETPLUGIN_H
+#define CUSTOMWIDGETPLUGIN_H
 
-#include <QtCore/qplugin.h>
-#include <QtGui/QIcon>
-
-class QDesignerFormEditorInterface;
+#include <QDesignerCustomWidgetInterface>
 
 class AnalogClockPlugin : public QObject, public QDesignerCustomWidgetInterface
 {
     Q_OBJECT
     Q_INTERFACES(QDesignerCustomWidgetInterface)
+
 public:
     AnalogClockPlugin(QObject *parent = 0);
+
     bool isContainer() const;
     bool isInitialized() const;
     QIcon icon() const;
-    QString codeTemplate() const;
     QString domXml() const;
     QString group() const;
     QString includeFile() const;
@@ -51,3 +49,5 @@ public:
 private:
     bool initialized;
 };
+
+#endif
