@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2004-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2004-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
@@ -102,7 +102,7 @@ void Window::createDateTimeEdits()
     QLabel *formatLabel = new QLabel(tr("Format string for the meeting date "
                                         "and time:"));
     QComboBox *formatComboBox = new QComboBox;
-    formatComboBox->addItem("yyyy-MM-dd hh:mm:ss (zzz ms)");
+    formatComboBox->addItem("yyyy-MM-dd hh:mm:ss (zzz 'ms')");
     formatComboBox->addItem("hh:mm:ss MM/dd/yyyy");
     formatComboBox->addItem("hh:mm:ss dd/MM/yyyy");
     formatComboBox->addItem("hh:mm:ss");
