@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
@@ -29,7 +29,6 @@
 #include "qstring.h"
 #include "qregexp.h"
 #include "qvector.h"
-#include "qdebug.h"
 
 #include <stdlib.h>
 
@@ -186,12 +185,10 @@ static int qt_cmp_si(const void *n1, const void *n2)
     QDirSortItem* f1 = (QDirSortItem*)n1;
     QDirSortItem* f2 = (QDirSortItem*)n2;
 
-    if (f1->item.isDir() != f2->item.isDir()) {
-        if (qt_cmp_si_sort_flags & QDir::DirsFirst)
-            return f1->item.isDir() ? -1 : 1;
-        if (qt_cmp_si_sort_flags & QDir::DirsLast)
-            return f1->item.isDir() ? 1 : -1;
-    }
+    if ((qt_cmp_si_sort_flags & QDir::DirsFirst) && (f1->item.isDir() != f2->item.isDir()))
+        return f1->item.isDir() ? -1 : 1;
+    if ((qt_cmp_si_sort_flags & QDir::DirsLast) && (f1->item.isDir() != f2->item.isDir()))
+        return f1->item.isDir() ? 1 : -1;
 
     int r = 0;
     int sortBy = (qt_cmp_si_sort_flags & QDir::SortByMask)
@@ -216,8 +213,8 @@ static int qt_cmp_si(const void *n1, const void *n2)
                                : f2->item.suffix();
 
 	r = qt_cmp_si_sort_flags & QDir::LocaleAware
-            ? f1->suffix_cache.localeAwareCompare(f2->filename_cache)
-            : f1->suffix_cache.compare(f2->filename_cache);
+            ? f1->suffix_cache.localeAwareCompare(f2->suffix_cache)
+            : f1->suffix_cache.compare(f2->suffix_cache);
       }
         break;
       default:
@@ -829,7 +826,7 @@ bool QDir::cd(const QString &dirName)
     }
     {
         QFileInfo fi(newPath);
-        if(!fi.exists())
+        if (!(fi.exists() && fi.isDir()))
             return false;
     }
 
@@ -952,15 +949,23 @@ QDir::Filters QDir::filter() const
     and directories will include symbolic links to files and directories
     unless you set the NoSymLinks value.
 
-    If you do not set any of Readable, Writable, or
-    Executable, QDir will set all three of them. This makes the
-    default easy to write, and at the same time useful.
+    A default constructed QDir will not filter out files based on
+    their permissions, so entryList() and entryInfoList() will return
+    all files that are readable, writable, executable, or any
+    combination of the three.  This makes the default easy to write,
+    and at the same time useful.
 
-    Examples: Readable | Writable means list all files for which the
-    application has read access, write access or both. Dirs | Drives
-    means list drives, directories, all files that the application can
-    read, write or execute, and also symlinks to such
-    files/directories.
+    For example, setting the \c Readable, \c Writable, and \c Files
+    flags allows all files to be listed for which the application has read
+    access, write access or both. If the \c Dirs and \c Drives flags are
+    also included in this combination then all drives, directories, all
+    files that the application can read, write, or execute, and symlinks
+    to such files/directories can be listed.
+
+    To retrieve the permissons for a directory, use the
+    entryInfoList() function to get the associated QFileInfo objects
+    and then use the QFileInfo::permissons() to obtain the permissions
+    and ownership for each file.
 */
 
 /*!
@@ -1010,6 +1015,7 @@ QDir::SortFlags QDir::sorting() const
     \value DirsLast Put the files first, then the directories.
     \value Reversed  Reverse the sort order.
     \value IgnoreCase  Sort case-insensitively.
+    \value LocaleAware Sort items appropriately using the current locale settings.
 
     \omitvalue SortByMask
     \omitvalue DefaultSort
@@ -1154,14 +1160,13 @@ QStringList QDir::entryList(const QStringList &nameFilters, Filters filters,
         d->updateFileLists();
         return d->data->files;
     }
-    QStringList l = d->data->fileEngine->entryList(filters, nameFilters), ret;
+    QStringList l = d->data->fileEngine->entryList(filters, nameFilters);
+    QStringList ret;
     d->sortFileList(sort, l, &ret, 0);
     return ret;
 }
 
 /*!
-    \overload
-
     Returns a list of QFileInfo objects for all the files and
     directories in the directory, ordered in accordance with
     setSorting() and filtered in accordance with setFilter() and
