@@ -28,6 +28,8 @@
 #include <QtCore/qpair.h>
 #include <QtCore/qstring.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Core)
 
 class QByteArray;
@@ -221,4 +223,6 @@ Q_CORE_EXPORT QDataStream &operator>>(QDataStream &, QUrl &);
 Q_CORE_EXPORT QDebug operator<<(QDebug, const QUrl &);
 #endif
 
+QT_END_HEADER
+
 #endif // QURL_H
