@@ -26,6 +26,8 @@
 
 #include <QtCore/qobject.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Core)
 
 class QEventLoopPrivate;
@@ -68,4 +70,6 @@ public Q_SLOTS:
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(QEventLoop::ProcessEventsFlags)
 
+QT_END_HEADER
+
 #endif // QEVENTLOOP_H
