@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
@@ -29,6 +29,8 @@
 #include <QtCore/qbasictimer.h> // conceptual inheritance
 #include <QtCore/qobject.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Core)
 
 class Q_CORE_EXPORT QTimer : public QObject
@@ -84,6 +86,8 @@ private:
 
 inline void QTimer::setSingleShot(bool asingleShot) { single = asingleShot; }
 
+QT_END_HEADER
+
 #endif // QT_NO_QOBJECT
 
 #endif // QTIMER_H
