@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
@@ -27,9 +27,11 @@
 #include <QtCore/qobject.h>
 #include <QtCore/qstringlist.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Core)
 
-struct QFactoryInterface
+struct Q_CORE_EXPORT QFactoryInterface
 {
     virtual ~QFactoryInterface() {}
     virtual QStringList keys() const = 0;
@@ -37,4 +39,6 @@ struct QFactoryInterface
 
 Q_DECLARE_INTERFACE(QFactoryInterface, "com.trolltech.Qt.QFactoryInterface")
 
+QT_END_HEADER
+
 #endif // QFACTORYINTERFACE_H
