@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
@@ -76,113 +76,6 @@
     \sa QLibrary
 */
 
-/*!
-    \macro Q_DECLARE_INTERFACE(ClassName, Identifier)
-    \relates QPluginLoader
-
-    This macro associates the given \a Identifier (a string literal)
-    to the interface class called \a ClassName. The \a Identifier must
-    be unique. For example:
-
-    \quotefromfile tools/plugandpaint/interfaces.h
-    \skipto Q_DECLARE_INTERFACE
-    \printuntil )
-
-    This macro is normally used right after the class definition for
-    \a ClassName, in a header file. See the
-    \l{tools/plugandpaint}{Plug & Paint} example for details.
-
-    If you want to use Q_DECLARE_INTERFACE with interface classes
-    declared in a namespace then you have to make sure the Q_DECLARE_INTERFACE
-    is not inside a namespace though. For example:
-    \code
-        namespace Foo
-        {
-            struct MyInterface { ... };
-        }
-        Q_DECLARE_INTERFACE(Foo::MyInterface, "org.examples.MyInterface")
-    \endcode
-
-    \sa Q_INTERFACES(), Q_EXPORT_PLUGIN(), {How to Create Qt Plugins}
-*/
-
-/*!
-    \macro Q_EXPORT_PLUGIN(ClassName)
-    \relates QPluginLoader
-    \obsolete
-
-    Use Q_EXPORT_PLUGIN2 instead. This macro is equivalent to
-    Q_EXPORT_PLUGIN2(\a ClassName, \a ClassName).
-*/
-
-/*!
-    \macro Q_EXPORT_PLUGIN2(PluginName, ClassName)
-    \relates QPluginLoader
-    \since 4.1
-
-    This macro exports the plugin class \a ClassName with the name \a
-    PluginName. There should be exactly one occurrence of this macro in a Qt
-    plugin's source code (in an implementation file).
-
-    Example:
-
-    \code
-        Q_EXPORT_PLUGIN2(pnp_extrafilters, ExtraFiltersPlugin)
-    \endcode
-
-    See the \l{tools/plugandpaint}{Plug & Paint} example for details.
-
-    \sa Q_DECLARE_INTERFACE(), {How to Create Qt Plugins}
-*/
-
-/*!
-    \macro Q_IMPORT_PLUGIN(ClassName)
-    \relates QPluginLoader
-
-    This macro imports the plugin class \a ClassName. Inserting this macro
-    into your application's source code will allow you to
-    make use of a static plugin.
-
-    Example:
-
-    \code
-        Q_IMPORT_PLUGIN(QJpegPlugin)
-    \endcode
-
-    Static plugins must also be included by the linker when your
-    application is built. With qmake, you can use QTPLUGIN to add
-    the required plugins to your build.
-
-    Example:
-
-    \code
-        TEMPLATE = app
-        QTPLUGIN += jpeg gif mng # image formats
-        QTPLUGIN += cn tw        # codecs
-    \endcode
-
-    Depending on your build, Qt provides the following static plugins:
-
-    \table
-    \header
-    \i Plugin class     \i Type     \i Description         \i QTPLUGIN entry
-    \row
-    \i QJpegPlugin      \i Image format \i The JPEG image format \i jpeg
-    \row
-    \i QGifPlugin      \i Image format \i The GIF image format \i gif
-    \row
-    \i QMngPlugin      \i Image format \i The MNG image format \i mng
-    \endtable
-
-    \sa {How to Create Qt Plugins}, {Using qmake}
-*/
-
-/*!
-    \macro Q_EXPORT_STATIC_PLUGIN(ClassName)
-    \relates QPluginLoader
-    \internal
-*/
-
 /*!
     Constructs a plugin loader with the given \a parent.
 */
@@ -335,7 +228,7 @@ bool QPluginLoader::isLoaded() const
 
     To be loadable, the file's suffix must be a valid suffix for a
     loadable library in accordance with the platform, e.g. \c .so on
-    Unix, - \c .dylib on Mac OS X, and \c .dll on Windows. The suffix
+    Unix, \c .dylib on Mac OS X, and \c .dll on Windows. The suffix
     can be verified with QLibrary::isLibrary().
 
     \sa load()
@@ -361,13 +254,18 @@ QString QPluginLoader::fileName() const
 typedef QList<QtPluginInstanceFunction> StaticInstanceFunctionList;
 Q_GLOBAL_STATIC(StaticInstanceFunctionList, staticInstanceFunctionList)
 
+/*!
+    \relates QPluginLoader
+
+    Registers the given \a function with the plugin loader.
+*/
 void Q_CORE_EXPORT qRegisterStaticPluginInstanceFunction(QtPluginInstanceFunction function)
 {
     staticInstanceFunctionList()->append(function);
 }
 
 /*!
-
+    Returns a list of static plugin instances held by the plugin loader.
 */
 QObjectList QPluginLoader::staticInstances()
 {
