@@ -26,6 +26,8 @@
 
 #include <QtCore/qbytearray.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Core)
 
 class QByteArrayMatcherPrivate;
@@ -51,4 +53,6 @@ private:
     uint q_skiptable[256];
 };
 
+QT_END_HEADER
+
 #endif // QBYTEARRAYMATCHER_H
