@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
@@ -579,6 +579,10 @@ void QMapData::dump()
     were inserted with insertMulti(), or unite() was used), also
     occur multiple times in the list.
 
+    To obtain a list of unique keys, where each key from the map only
+    occurs once, use an intermediate QSet object to filter out
+    duplicates.
+
     The order is guaranteed to be the same as that used by values().
 
     \sa values(), key()
@@ -1558,8 +1562,19 @@ void QMapData::dump()
 /*!
     \fn iterator QMap::insert(const Key &key, const T &value, bool overwrite);
 
-    Use the two-argument insert() overload instead. If you want to
-    overwrite, remove() then insert().
+    Use the two-argument insert() overload instead. If you don't want
+    to overwrite, call contains() beforehand.
+
+    \oldcode
+        QMap<QString, int> map;
+        ...
+        map.insert("delay", 30000, false);
+    \newcode
+        QMap<QString, int> map;
+        ...
+        if (!map.contains("delay"))
+            map.insert("delay", 30000);
+    \endcode
 */
 
 /*!
