@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
@@ -34,6 +34,8 @@
 
 #include <new>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Core)
 
 struct Q_CORE_EXPORT QMapData
@@ -852,4 +854,6 @@ Q_INLINE_TEMPLATE Q_TYPENAME QMap<Key, T>::iterator QMultiMap<Key, T>::insert(co
 Q_DECLARE_ASSOCIATIVE_ITERATOR(Map)
 Q_DECLARE_MUTABLE_ASSOCIATIVE_ITERATOR(Map)
 
+QT_END_HEADER
+
 #endif // QMAP_H
