@@ -26,6 +26,8 @@
 
 #include <QtCore/qdatastream.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Core)
 
 template <class T1, class T2>
@@ -98,4 +100,6 @@ inline QDataStream& operator<<(QDataStream& s, const QPair<T1, T2>& p)
 }
 #endif
 
+QT_END_HEADER
+
 #endif // QPAIR_H
