@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
@@ -26,6 +26,8 @@
 
 #include <QtCore/qnamespace.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Core)
 
 class Q_CORE_EXPORT QSize
@@ -335,4 +337,6 @@ inline QSize QSizeF::toSize() const
 Q_CORE_EXPORT QDebug operator<<(QDebug, const QSizeF &);
 #endif
 
+QT_END_HEADER
+
 #endif // QSIZE_H
