@@ -26,6 +26,8 @@
 
 #include <QtGui/qaccessible.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Gui)
 
 #ifndef QT_NO_ACCESSIBILITY
@@ -84,4 +86,6 @@ public:
 
 #endif // QT_NO_ACCESSIBILITY
 
+QT_END_HEADER
+
 #endif // QACCESSIBLEOBJECT_H
