@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
@@ -28,6 +28,8 @@
 #include <QtCore/qsize.h>
 #include <QtGui/qpixmap.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Gui)
 
 class QIconPrivate;
@@ -95,4 +97,6 @@ Q_DECLARE_TYPEINFO(QIcon, Q_MOVABLE_TYPE);
 typedef QIcon QIconSet;
 #endif
 
+QT_END_HEADER
+
 #endif // QICON_H
