@@ -26,6 +26,8 @@
 
 #include <QtCore/qbytearray.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Gui)
 
 class QColor;
@@ -103,4 +105,6 @@ private:
     QImageReaderPrivate *d;
 };
 
+QT_END_HEADER
+
 #endif // QIMAGEREADER_H
