@@ -26,6 +26,8 @@
 
 #include <QtGui/qabstractitemview.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Gui)
 
 #ifndef QT_NO_ITEMVIEWS
@@ -179,7 +181,7 @@ protected:
     QRegion visualRegionForSelection(const QItemSelection &selection) const;
 
 private:
-    Q_PRIVATE_SLOT(d_func(), void sectionsRemoved(const QModelIndex &parent, int logicalFirst, int logicalLast))
+    Q_PRIVATE_SLOT(d_func(), void _q_sectionsRemoved(const QModelIndex &parent, int logicalFirst, int logicalLast))
     Q_DECLARE_PRIVATE(QHeaderView)
     Q_DISABLE_COPY(QHeaderView)
 };
@@ -197,4 +199,6 @@ inline void QHeaderView::showSection(int alogicalIndex)
 
 #endif // QT_NO_ITEMVIEWS
 
+QT_END_HEADER
+
 #endif // QHEADERVIEW_H
