@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
@@ -48,6 +48,9 @@ public:
     QItemSelection expandSelection(const QItemSelection &selection,
                                    QItemSelectionModel::SelectionFlags command) const;
 
+    void _q_rowsAboutToBeRemoved(const QModelIndex &parent, int start, int end);
+    void _q_columnsAboutToBeRemoved(const QModelIndex &parent, int start, int end);
+
     inline void remove(QList<QItemSelectionRange> &r)
     {
         QList<QItemSelectionRange>::const_iterator it = r.constBegin();
@@ -55,6 +58,13 @@ public:
             ranges.removeAll(*it);
     }
 
+    inline void finalize()
+    {
+        ranges.merge(currentSelection, currentCommand);
+        currentSelection.clear();
+    }
+
+
     QPointer<QAbstractItemModel> model;
     QItemSelection ranges;
     QItemSelection currentSelection;
