@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
@@ -22,6 +22,9 @@
 ****************************************************************************/
 
 #include "qsortfilterproxymodel.h"
+
+#ifndef QT_NO_SORTFILTERPROXYMODEL
+
 #include "qitemselectionmodel.h"
 #include <qsize.h>
 #include <qdebug.h>
@@ -58,7 +61,7 @@ public:
                                           const QAbstractItemModel *source,
                                           const QSortFilterProxyModel *proxy)
         : sort_column(column), source_parent(parent), source_model(source), proxy_model(proxy) {}
-    
+
     inline bool operator()(int r1, int r2) const
     {
         QModelIndex i1 = source_model->index(r1, sort_column, source_parent);
@@ -111,6 +114,7 @@ public:
         QMap<QModelIndex, Mapping *>::const_iterator it =
             reinterpret_cast<QMap<QModelIndex, Mapping *>::const_iterator & >(p);
         Q_ASSERT(it != source_index_mapping.end());
+        Q_ASSERT(it.value());
         return it;
     }
 
@@ -121,22 +125,16 @@ public:
         return q_func()->createIndex(row, column, const_cast<void *>(p));
     }
 
-    inline Mapping *index_to_mapping(const QModelIndex &proxy_parent) const
-    {
-        if (!proxy_parent.isValid())
-            return create_mapping(QModelIndex()).value();
-        QMap<QModelIndex, QSortFilterProxyModelPrivate::Mapping *>::const_iterator it
-            = index_to_iterator(proxy_parent); // parent should be mapped already
-        QSortFilterProxyModelPrivate::Mapping *m = it.value();
-        Q_ASSERT(m);
-        return m;
-    }
-
-    void sourceDataChanged(const QModelIndex &source_top_left,
+    void _q_sourceDataChanged(const QModelIndex &source_top_left,
                            const QModelIndex &source_bottom_right);
-    void sourceHeaderDataChanged(Qt::Orientation orientation, int start, int end);
-    void sourceLayoutChanged();
-    void clear();
+    void _q_sourceHeaderDataChanged(Qt::Orientation orientation, int start, int end);
+
+    void _q_sourceLayoutAboutToBeChanged(const QModelIndex &source_parent);
+    void _q_sourceLayoutChanged();
+
+    void _q_sourceReset();
+
+    void clear_mapping();
 };
 
 typedef QMap<QModelIndex, QSortFilterProxyModelPrivate::Mapping *> IndexMap;
@@ -150,7 +148,7 @@ void QSortFilterProxyModelPrivate::remove_from_mapping(const QModelIndex &source
     }
 }
 
-void QSortFilterProxyModelPrivate::clear()
+void QSortFilterProxyModelPrivate::clear_mapping()
 {
     // store the persistent indexes
     QModelIndexList source_indexes;
@@ -189,7 +187,6 @@ IndexMap::const_iterator QSortFilterProxyModelPrivate::create_mapping(
         if (q->filterAcceptsRow(i, source_parent))
             m->source_rows.append(i);
     }
-
     int source_cols = model->columnCount(source_parent);
     for (int i = 0; i < source_cols; ++i) {
         if (q->filterAcceptsColumn(i, source_parent))
@@ -223,6 +220,9 @@ IndexMap::const_iterator QSortFilterProxyModelPrivate::create_mapping(
         it2.value()->mapped_children.append(source_parent);
     }
 
+    Q_ASSERT(it != source_index_mapping.end());
+    Q_ASSERT(it.value());
+
     return it;
 }
 
@@ -231,8 +231,9 @@ QModelIndex QSortFilterProxyModelPrivate::proxy_to_source(const QModelIndex &pro
     if (!proxy_index.isValid())
         return QModelIndex(); // for now; we may want to be able to set a root index later
     IndexMap::const_iterator it = index_to_iterator(proxy_index);
-    Q_ASSERT(it != source_index_mapping.end());
     Mapping *m = it.value();
+    if ((proxy_index.row() >= m->source_rows.size()) || (proxy_index.column() >= m->source_columns.size()))
+        return QModelIndex();
     int source_row = m->source_rows.at(proxy_index.row());
     int source_col = m->source_columns.at(proxy_index.column());
     return model->index(source_row, source_col, it.key());
@@ -244,14 +245,15 @@ QModelIndex QSortFilterProxyModelPrivate::source_to_proxy(const QModelIndex &sou
         return QModelIndex(); // for now; we may want to be able to set a root index later
     QModelIndex source_parent = source_index.parent();
     IndexMap::const_iterator it = create_mapping(source_parent);
-    Q_ASSERT(it != source_index_mapping.end());
     Mapping *m = it.value();
+    if ((source_index.row() >= m->proxy_rows.size()) || (source_index.column() >= m->proxy_columns.size()))
+        return QModelIndex();
     int proxy_row = m->proxy_rows.at(source_index.row());
     int proxy_column = m->proxy_columns.at(source_index.column());
     return create_index(proxy_row, proxy_column, it);
 }
 
-void QSortFilterProxyModelPrivate::sourceDataChanged(const QModelIndex &source_top_left,
+void QSortFilterProxyModelPrivate::_q_sourceDataChanged(const QModelIndex &source_top_left,
                                                      const QModelIndex &source_bottom_right)
 {
     Q_Q(QSortFilterProxyModel);
@@ -260,7 +262,7 @@ void QSortFilterProxyModelPrivate::sourceDataChanged(const QModelIndex &source_t
     emit q->dataChanged(proxy_top_left, proxy_bottom_right);
 }
 
-void QSortFilterProxyModelPrivate::sourceHeaderDataChanged(Qt::Orientation orientation,
+void QSortFilterProxyModelPrivate::_q_sourceHeaderDataChanged(Qt::Orientation orientation,
                                                            int start, int end)
 {
     Q_Q(QSortFilterProxyModel);
@@ -274,44 +276,195 @@ void QSortFilterProxyModelPrivate::sourceHeaderDataChanged(Qt::Orientation orien
     emit q->headerDataChanged(orientation, proxy_start, proxy_end);
 }
 
-void QSortFilterProxyModelPrivate::sourceLayoutChanged()
+void QSortFilterProxyModelPrivate::_q_sourceLayoutAboutToBeChanged(const QModelIndex &source_parent)
 {
     Q_Q(QSortFilterProxyModel);
-    qDeleteAll(source_index_mapping);
-    source_index_mapping.clear();
+    const QModelIndex proxy_parent = source_to_proxy(source_parent);;
+    int first = 0;
+    int last = q->rowCount(proxy_parent) - 1;
+    changes.push(QAbstractItemModelPrivate::Change(proxy_parent, first, last));
+    if (last >= first)
+        rowsAboutToBeRemoved(proxy_parent, first, last);
+    remove_from_mapping(source_parent);
+}
+
+void QSortFilterProxyModelPrivate::_q_sourceLayoutChanged()
+{
+    Q_Q(QSortFilterProxyModel);
+    QAbstractItemModelPrivate::Change change = changes.pop();
+    if (change.last >= change.first)
+        rowsRemoved(change.parent, change.first, change.last);
+    emit q->layoutChanged();
+}
+
+void QSortFilterProxyModelPrivate::_q_sourceReset()
+{
+    Q_Q(QSortFilterProxyModel);
+    // All internal structures are deleted in clear()
     q->reset();
 }
 
 /*!
-  \since 4.1
-  \class QSortFilterProxyModel
-  \brief The QSortFilterProxyModel class provides support for sorting and filtering data passed
-  between another model and a view.
-  \ingroup model-view
+    \since 4.1
+    \class QSortFilterProxyModel
+    \brief The QSortFilterProxyModel class provides support for sorting and filtering data passed
+    between another model and a view.
 
-  The sorting filter model transform the structure of a source model by mapping the model indexes
-  it supplies to new indexes, corresponding to different locations, for views to use.
-  This approach allows a given source model to be restructured as far as views are concerned
-  without requiring any transformations on the underlying data.
-  
-  The default implementation of the filter and sorting functions use the data for the items
-  Qt::DisplayRole compare or accept items.
+    \ingroup model-view
 
-  The default implementation of the lessThan() function used when sorting, can handle the
-  following data types:
-  \list
-  \o QVariant::Int
-  \o QVariant::UInt
-  \o QVariant::LongLong
-  \o QVariant::ULongLong
-  \o QVariant::Double
-  \o QVariant::Char
-  \o QVariant::Date
-  \o QVariant::Time
-  \o QVariant::DateTime
-  \o QVariant::String
-  
-  \sa QAbstractProxyModel, QAbstractItemModel, {Model/View Programming}
+    QSortFilterProxyModel can be used for sorting items, filtering
+    out items, or both. The model transforms the structure of a
+    source model by mapping the model indexes it supplies to new
+    indexes, corresponding to different locations, for views to use.
+    This approach allows a given source model to be restructured as
+    far as views are concerned without requiring any transformations
+    on the underlying data, and without duplicating the data in
+    memory.
+
+    Let's assume that we want to sort and filter the items provided
+    by a custom model. The code to set up the model and the view, \e
+    without sorting and filtering, would look like this:
+
+    \code
+        QTreeView *treeView = new QTreeView;
+        MyItemModel *model = new MyItemModel(this);
+
+        treeView->setModel(model);
+    \endcode
+
+    To add sorting and filtering support to \c MyItemModel, we need
+    to create a QSortFilterProxyModel, call setSourceModel() with the
+    \c MyItemModel as argument, and install the QSortFilterProxyModel
+    on the view:
+
+    \code
+        QTreeView *treeView = new QTreeView;
+        MyItemModel *sourceModel = new MyItemModel(this);
+        QSortFilterProxyModel *proxyModel = new QSortFilterProxyModel(this);
+
+        proxyModel->setSourceModel(sourceModel);
+        treeView->setModel(proxyModel);
+    \endcode
+
+    At this point, neither sorting nor filtering is enabled; the
+    original data is displayed in the view. Any changes made through
+    the QSortFilterProxyModel are applied to the original model.
+
+    The QSortFilterProxyModel acts as a wrapper for the original
+    model. If you need to convert source \l{QModelIndex}es to
+    sorted/filtered model indexes or vice versa, use mapToSource(),
+    mapFromSource(), mapSelectionToSource(), and
+    mapSelectionFromSource().
+
+    By default, sorting and filtering isn't dynamically reapplied
+    whenever the data of the original model changes, as an
+    optimization. To enable dynamic sorting and filtering, call
+    setDynamicSortFilter(true). At any time, you can call clear() to
+    resort/refilter the data.
+
+    \section1 Sorting
+
+    QHeaderView has a \l
+    {QHeaderVIew::showSortIndicator()}{showSortIndicator()} property
+    and a \l {QHeaderView::setClickable()}{setClickable()} function
+    that together control whether the user can sort the view by
+    clicking the view's horizontal header. For example:
+
+    \code
+        treeView->header()->setClickable(true);
+        treeView->header()->setSortIndicatorShown(true);
+    \endcode
+
+    When this feature is on, clicking on a header section sorts the
+    items according to that column. By clicking repeatedly, the user
+    can alternate between ascending and descending order.
+
+    \image qsortfilterproxymodel-sorting.png A sorted QTreeView
+
+    Behind the scene, the view calls the sort() virtual function on
+    the model to reorder the data in the model. To make your data
+    sortable, you can either implement sort() in your model, or you
+    use a QSortFilterProxyModel to wrap your model --
+    QSortFilterProxyModel provides a generic sort() reimplementation
+    that operates on the Qt::DisplayRole of the items and that
+    understands several data types, including \c int, QString, and
+    QDateTime. For hierarchical models, sorting is applied
+    recursively to all child items. String comparisons are case
+    sensitive.
+
+    Custom sorting behavior is achieved by subclassing
+    QSortFilterProxyModel and reimplementing lessThan(), which is
+    used to compare items. For example:
+
+    \code
+        bool MySortFilterProxyModel::lessThan(const QModelIndex &left,
+                                              const QModelIndex &right) const
+        {
+            QVariant leftData = sourceModel()->data(left);
+            QVariant rightData = sourceModel()->data(right);
+
+            if (leftData.type() == QVariant::DateTime) {
+                return leftData.toDateTime() < rightData.toDateTime();
+            } else {
+                return QString::localeAwareCompare(leftData.toString(),
+                                                   rightData.toString()) < 0;
+            }
+        }
+    \endcode
+
+    An alternative approach to sorting is to disable sorting on the
+    view and to impose a certain order to the user. This is done by
+    explicitly calling sort() with the desired column and order as
+    arguments on the QSortFilterProxyModel (or on the original model
+    if it implements sort()). For example:
+
+    \code
+        proxyModel->sort(2, Qt::AscendingOrder);
+    \endcode
+
+    The \l{itemviews/sortingmodel}{Sorting Model} example illustrates
+    how to use QSortFilterProxyModel to perform basic sorting.
+
+    \section1 Filtering
+
+    In addition to sorting, QSortFilterProxyModel can be used to hide
+    items that don't match a certain filter. The filter is specified
+    using a QRegExp object and is applied to the  Qt::DisplayRole of
+    each item, for a given column. The QRegExp object can be used to
+    match a regular expression, a wildcard pattern, or a fixed
+    string. For example:
+
+    \code
+        proxyModel->setFilterRegExp(QRegExp(".png", Qt::CaseInsensitive,
+                                            QRegExp::FixedString));
+        proxyModel->setFilterKeyColumn(1);
+    \endcode
+
+    For hierarchical models, the filter is applied recursively to all
+    children. If a parent item doesn't match the filter, none of its
+    children will be shown.
+
+    Custom filtering behavior can be achieved by reimplementing the
+    filterAcceptsRow() and filterAcceptsColumn() functions. For
+    example, the following implementation ignores the \l
+    filterKeyColumn property and performs filtering on columns 0, 1,
+    and 2:
+
+    \code
+        bool MySortFilterProxyModel::filterAcceptsRow(int sourceRow,
+                const QModelIndex &sourceParent) const
+        {
+            QModelIndex index0 = sourceModel()->index(sourceRow, 0, sourceParent);
+            QModelIndex index1 = sourceModel()->index(sourceRow, 1, sourceParent);
+            QModelIndex index2 = sourceModel()->index(sourceRow, 2, sourceParent);
+
+            return (sourceModel()->data(index0).toString().contains(filterRegExp())
+                    || sourceModel()->data(index1).toString().contains(filterRegExp()))
+                   && dateInRange(sourceModel()->data(index2).toDate());
+        }
+    \endcode
+
+    \sa QAbstractProxyModel, QAbstractItemModel, {Model/View Programming}
 */
 
 /*!
@@ -329,7 +482,7 @@ QSortFilterProxyModel::QSortFilterProxyModel(QObject *parent)
 }
 
 /*!
-    Destroys the sorting filter model.
+    Destroys this sorting filter model.
 */
 QSortFilterProxyModel::~QSortFilterProxyModel()
 {
@@ -347,53 +500,80 @@ void QSortFilterProxyModel::setSourceModel(QAbstractItemModel *sourceModel)
 
     if (d->model && d->model != &d->empty) {
         disconnect(d->model, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-                   this, SLOT(sourceDataChanged(QModelIndex,QModelIndex)));
+                   this, SLOT(_q_sourceDataChanged(QModelIndex,QModelIndex)));
 
         disconnect(d->model, SIGNAL(headerDataChanged(Qt::Orientation,int,int)),
-                   this, SLOT(sourceHeaderDataChanged(Qt::Orientation,int,int)));
+                   this, SLOT(_q_sourceHeaderDataChanged(Qt::Orientation,int,int)));
+
+        disconnect(d->model, SIGNAL(rowsAboutToBeInserted(QModelIndex,int,int)),
+                   this, SLOT(_q_sourceLayoutAboutToBeChanged(QModelIndex)));
 
         disconnect(d->model, SIGNAL(rowsInserted(QModelIndex,int,int)),
-                   this, SLOT(sourceLayoutChanged()));
+                   this, SLOT(_q_sourceLayoutChanged()));
+
+        disconnect(d->model, SIGNAL(columnsAboutToBeInserted(QModelIndex,int,int)),
+                   this, SLOT(_q_sourceLayoutAboutToBeChanged(QModelIndex)));
 
         disconnect(d->model, SIGNAL(columnsInserted(QModelIndex,int,int)),
-                   this, SLOT(sourceLayoutChanged()));
+                   this, SLOT(_q_sourceLayoutChanged()));
+
+        disconnect(d->model, SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)),
+                   this, SLOT(_q_sourceLayoutAboutToBeChanged(QModelIndex)));
 
         disconnect(d->model, SIGNAL(rowsRemoved(QModelIndex,int,int)),
-                   this, SLOT(sourceLayoutChanged()));
+                   this, SLOT(_q_sourceLayoutChanged()));
+
+        disconnect(d->model, SIGNAL(columnsAboutToBeRemoved(QModelIndex,int,int)),
+                   this, SLOT(_q_sourceLayoutAboutToBeChanged(QModelIndex)));
 
         disconnect(d->model, SIGNAL(columnsRemoved(QModelIndex,int,int)),
-                   this, SLOT(sourceLayoutChanged()));
+                   this, SLOT(_q_sourceLayoutChanged()));
 
-        disconnect(d->model, SIGNAL(modelReset()), this, SLOT(sourceLayoutChanged()));
-        disconnect(d->model, SIGNAL(layoutChanged()), this, SLOT(sourceLayoutChanged()));
+        disconnect(d->model, SIGNAL(modelReset()), this, SLOT(_q_sourceReset()));
+        disconnect(d->model, SIGNAL(layoutChanged()), this, SLOT(clear()));
     }
 
     QAbstractProxyModel::setSourceModel(sourceModel);
 
     if (sourceModel) {
         connect(d->model, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-                this, SLOT(sourceDataChanged(QModelIndex,QModelIndex)));
+                this, SLOT(_q_sourceDataChanged(QModelIndex,QModelIndex)));
 
         connect(d->model, SIGNAL(headerDataChanged(Qt::Orientation,int,int)),
-                this, SLOT(sourceHeaderDataChanged(Qt::Orientation,int,int)));
+                this, SLOT(_q_sourceHeaderDataChanged(Qt::Orientation,int,int)));
+
+        connect(d->model, SIGNAL(rowsAboutToBeInserted(QModelIndex,int,int)),
+                this, SLOT(_q_sourceLayoutAboutToBeChanged(QModelIndex)));
 
         connect(d->model, SIGNAL(rowsInserted(QModelIndex,int,int)),
-                this, SLOT(sourceLayoutChanged()));
+                this, SLOT(_q_sourceLayoutChanged()));
+
+        connect(d->model, SIGNAL(columnsAboutToBeInserted(QModelIndex,int,int)),
+                this, SLOT(_q_sourceLayoutAboutToBeChanged(QModelIndex)));
+
+        connect(d->model, SIGNAL(columnsAboutToBeInserted(QModelIndex,int,int)),
+                this, SLOT(_q_sourceLayoutAboutToBeChanged(QModelIndex)));
 
         connect(d->model, SIGNAL(columnsInserted(QModelIndex,int,int)),
-                this, SLOT(sourceLayoutChanged()));
+                this, SLOT(_q_sourceLayoutChanged()));
+
+        connect(d->model, SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)),
+                this, SLOT(_q_sourceLayoutAboutToBeChanged(QModelIndex)));
 
         connect(d->model, SIGNAL(rowsRemoved(QModelIndex,int,int)),
-                this, SLOT(sourceLayoutChanged()));
+                this, SLOT(_q_sourceLayoutChanged()));
+
+        connect(d->model, SIGNAL(columnsAboutToBeRemoved(QModelIndex,int,int)),
+                this, SLOT(_q_sourceLayoutAboutToBeChanged(QModelIndex)));
 
         connect(d->model, SIGNAL(columnsRemoved(QModelIndex,int,int)),
-                this, SLOT(sourceLayoutChanged()));
+                this, SLOT(_q_sourceLayoutChanged()));
 
-        connect(d->model, SIGNAL(modelReset()), this, SLOT(sourceLayoutChanged()));
-        connect(d->model, SIGNAL(layoutChanged()), this, SLOT(sourceLayoutChanged()));
+        connect(d->model, SIGNAL(modelReset()), this, SLOT(_q_sourceReset()));
+        connect(d->model, SIGNAL(layoutChanged()), this, SLOT(clear()));
     }
 
-    d->clear();
+    d->clear_mapping();
 }
 
 /*!
@@ -402,8 +582,14 @@ void QSortFilterProxyModel::setSourceModel(QAbstractItemModel *sourceModel)
 QModelIndex QSortFilterProxyModel::index(int row, int column, const QModelIndex &parent) const
 {
     Q_D(const QSortFilterProxyModel);
+    if (row < 0 || column < 0)
+        return QModelIndex();
+
     QModelIndex source_parent = d->proxy_to_source(parent); // parent is already mapped at this point
     IndexMap::const_iterator it = d->create_mapping(source_parent); // but make sure that the children are mapped
+    if (it.value()->source_rows.count() <= row || it.value()->source_columns.count() <= column)
+        return QModelIndex();
+
     return d->create_index(row, column, it);
 }
 
@@ -453,7 +639,7 @@ bool QSortFilterProxyModel::hasChildren(const QModelIndex &parent) const
     QModelIndex source_parent = d->proxy_to_source(parent);
     if (!d->model->hasChildren(source_parent))
         return false;
-    QSortFilterProxyModelPrivate::Mapping *m = d->index_to_mapping(parent);
+    QSortFilterProxyModelPrivate::Mapping *m = d->create_mapping(source_parent).value();
     return m->source_rows.count() != 0 && m->source_columns.count() != 0;
 }
 
@@ -484,9 +670,19 @@ QVariant QSortFilterProxyModel::headerData(int section, Qt::Orientation orientat
 {
     Q_D(const QSortFilterProxyModel);
     IndexMap::const_iterator it = d->create_mapping(QModelIndex());
-    int source_section = (orientation == Qt::Vertical
-                          ? it.value()->source_rows.at(section)
-                          : it.value()->source_columns.at(section));
+
+    int source_section;
+    if (orientation == Qt::Vertical) {
+        if (section < 0 || section >= it.value()->source_rows.count())
+            return QVariant();
+        source_section = it.value()->source_rows.at(section);
+    }
+    else {
+        if (section < 0 || section >= it.value()->source_columns.count())
+            return QVariant();
+        source_section = it.value()->source_columns.at(section);
+    }
+
     return d->model->headerData(source_section, orientation, role);
 }
 
@@ -498,9 +694,19 @@ bool QSortFilterProxyModel::setHeaderData(int section, Qt::Orientation orientati
 {
     Q_D(QSortFilterProxyModel);
     IndexMap::const_iterator it = d->create_mapping(QModelIndex());
-    int source_section = (orientation == Qt::Vertical
-                          ? it.value()->source_rows.at(section)
-                          : it.value()->source_columns.at(section));
+
+    int source_section;
+    if (orientation == Qt::Vertical) {
+        if (section < 0 || section >= it.value()->source_rows.count())
+            return false;
+        source_section = it.value()->source_rows.at(section);
+    }
+    else {
+        if (section < 0 || section >= it.value()->source_columns.count())
+            return false;
+        source_section = it.value()->source_columns.at(section);
+    }
+
     return d->model->setHeaderData(source_section, orientation, value, role);
 }
 
@@ -535,12 +741,15 @@ bool QSortFilterProxyModel::dropMimeData(const QMimeData *data, Qt::DropAction a
 bool QSortFilterProxyModel::insertRows(int row, int count, const QModelIndex &parent)
 {
     Q_D(QSortFilterProxyModel);
+    if (row < 0 || count <= 0)
+        return false;
     QModelIndex source_parent = d->proxy_to_source(parent);
     QSortFilterProxyModelPrivate::Mapping *m = d->create_mapping(source_parent).value();
+    if (row > m->source_rows.count())
+        return false;
     int source_row = (row >= m->source_rows.count()
                       ? m->source_rows.count()
                       : m->source_rows.at(row));
-    d->remove_from_mapping(source_parent);
     return d->model->insertRows(source_row, count, source_parent);
 }
 
@@ -550,12 +759,15 @@ bool QSortFilterProxyModel::insertRows(int row, int count, const QModelIndex &pa
 bool QSortFilterProxyModel::insertColumns(int column, int count, const QModelIndex &parent)
 {
     Q_D(QSortFilterProxyModel);
+    if (column < 0|| count <= 0)
+        return false;
     QModelIndex source_parent = d->proxy_to_source(parent);
     QSortFilterProxyModelPrivate::Mapping *m = d->create_mapping(source_parent).value();
+    if (column > m->source_columns.count())
+        return false;
     int source_column = (column >= m->source_columns.count()
                          ? m->source_columns.count()
                          : m->source_columns.at(column));
-    d->remove_from_mapping(source_parent);
     return d->model->insertColumns(source_column, count, source_parent);
 }
 
@@ -565,12 +777,15 @@ bool QSortFilterProxyModel::insertColumns(int column, int count, const QModelInd
 bool QSortFilterProxyModel::removeRows(int row, int count, const QModelIndex &parent)
 {
     Q_D(QSortFilterProxyModel);
+    if (row < 0 || count <= 0)
+        return false;
     QModelIndex source_parent = d->proxy_to_source(parent);
     QSortFilterProxyModelPrivate::Mapping *m = d->create_mapping(source_parent).value();
+    if (row + count > m->source_rows.count())
+        return false;
     int source_row = (row >= m->source_rows.count()
                       ? m->source_rows.at(m->source_rows.count()) + 1
                       : m->source_rows.at(row));
-    d->remove_from_mapping(source_parent);
     return d->model->removeRows(source_row, count, source_parent);
 }
 
@@ -580,12 +795,15 @@ bool QSortFilterProxyModel::removeRows(int row, int count, const QModelIndex &pa
 bool QSortFilterProxyModel::removeColumns(int column, int count, const QModelIndex &parent)
 {
     Q_D(QSortFilterProxyModel);
+    if (column < 0 || count <= 0)
+        return false;
     QModelIndex source_parent = d->proxy_to_source(parent);
     QSortFilterProxyModelPrivate::Mapping *m = d->create_mapping(source_parent).value();
+    if (column + count > m->source_columns.count())
+        return false;
     int source_column = (column >= m->source_columns.count()
                          ? m->source_columns.at(m->source_columns.count()) + 1
                          : m->source_columns.at(column));
-    d->remove_from_mapping(source_parent);
     return d->model->removeColumns(source_column, count, source_parent);
 }
 
@@ -680,7 +898,7 @@ void QSortFilterProxyModel::sort(int column, Qt::SortOrder order)
     \property QSortFilterProxyModel::filterRegExp
     \brief the QRegExp used to filter the contents of the source model
 
-    Setting this property overwrites the current \l caseSensitivity.
+    Setting this property overwrites the current \l filterCaseSensitivity.
 
     \sa setCaseSensitivity(), setFilterWildcard(), setFilterFixedString()
 */
@@ -698,9 +916,11 @@ void QSortFilterProxyModel::setFilterRegExp(const QRegExp &regExp)
 }
 
 /*!
-  \property QSortFilterProxyModel::filterKeyColumn
-  \brief the column where the key used to filter the contents
-  of the source model is read from.
+    \property QSortFilterProxyModel::filterKeyColumn
+    \brief the column where the key used to filter the contents of the
+    source model is read from.
+
+    The default value is 0.
 */
 int QSortFilterProxyModel::filterKeyColumn() const
 {
@@ -717,8 +937,13 @@ void QSortFilterProxyModel::setFilterKeyColumn(int column)
 }
 
 /*!
-    Returns the case sensitivity of the QRegExp pattern used to filter the
-    contents of the source model. By default, the filter is case sensistive.
+    \property QSortFilterProxyModel::filterCaseSensitivity
+    \brief the case sensitivity of the QRegExp pattern used to filter the
+    contents of the source model.
+
+    By default, the filter is case sensistive.
+
+    \sa setFilterRegExp(), setFilterWildcard(), setFilterFixedString()
 */
 Qt::CaseSensitivity QSortFilterProxyModel::filterCaseSensitivity() const
 {
@@ -726,12 +951,6 @@ Qt::CaseSensitivity QSortFilterProxyModel::filterCaseSensitivity() const
     return d->filter_regexp.caseSensitivity();
 }
 
-/*!
-    Sets the case sensitivity of the QRegExp pattern used to filter the contents
-    of the source model to \a cs. By default, the filter is case sensitive.
-
-    \sa setFilterRegExp(), setFilterWildcard(), setFilterFixedString()
-*/
 void QSortFilterProxyModel::setFilterCaseSensitivity(Qt::CaseSensitivity cs)
 {
     Q_D(QSortFilterProxyModel);
@@ -759,7 +978,7 @@ void QSortFilterProxyModel::setFilterRegExp(const QString &pattern)
 
 /*!
     Sets the wildcard expression used to filter the contents
-    of the source model to \a pattern.
+    of the source model to the given \a pattern.
 
     \sa setFilterCaseSensitivity(), setFilterRegExp(), setFilterFixedString()
 */
@@ -773,7 +992,7 @@ void QSortFilterProxyModel::setFilterWildcard(const QString &pattern)
 
 /*!
     Sets the fixed string used to filter the contents
-    of the source model to \a pattern.
+    of the source model to the given \a pattern.
 
     \sa setFilterCaseSensitivity(), setFilterRegExp(), setFilterWildcard()
 */
@@ -786,39 +1005,41 @@ void QSortFilterProxyModel::setFilterFixedString(const QString &pattern)
 }
 
 /*!
-  Clears the sorting filter model, removing all mapping.
+    Clears this sorting filter model, removing all mapping.
 */
 void QSortFilterProxyModel::clear()
 {
     Q_D(QSortFilterProxyModel);
-    d->clear();
+    d->clear_mapping();
     emit layoutChanged();
 }
 
 /*!
-  Returns true if the value of the item referred to by the given index \a left
-  is less than the value of the item referred to by the given index \a right,
-  otherwise returns false.
-  This function is used as the < operator when sorting, and handles several
-  QVariant types:
+    Returns true if the value of the item referred to by the given
+    index \a left is less than the value of the item referred to by
+    the given index \a right, otherwise returns false.  This function
+    is used as the < operator when sorting, and handles several
+    QVariant types:
 
-  \list
-  \o QVariant::Int
-  \o QVariant::UInt
-  \o QVariant::LongLong
-  \o QVariant::ULongLong
-  \o QVariant::Double
-  \o QVariant::Char
-  \o QVariant::Date
-  \o QVariant::Time
-  \o QVariant::DateTime
-  \o QVariant::String
+    \list
+        \o QVariant::Int
+        \o QVariant::UInt
+        \o QVariant::LongLong
+        \o QVariant::ULongLong
+        \o QVariant::Double
+        \o QVariant::Char
+        \o QVariant::Date
+        \o QVariant::Time
+        \o QVariant::DateTime
+        \o QVariant::String
+    \endlist
+
+    \sa sort()
 */
 bool QSortFilterProxyModel::lessThan(const QModelIndex &left, const QModelIndex &right) const
 {
     QVariant l = (left.model() ? left.model()->data(left, Qt::DisplayRole) : QVariant());
     QVariant r = (right.model() ? right.model()->data(right, Qt::DisplayRole) : QVariant());
-    Q_ASSERT(l.type() == r.type());
     switch (l.type()) {
     case QVariant::Int:
         return l.toInt() < r.toInt();
@@ -846,10 +1067,15 @@ bool QSortFilterProxyModel::lessThan(const QModelIndex &left, const QModelIndex
 }
 
 /*!
-  Returns true if the value in the item in the row indicated by
-  the given \a source_row and \a source_parent should be included in the model.
-  The default implementation uses filterRegExp with the data returned for the Qt::DisplayRole
-  to determine if the row should be accepted or not.
+    Returns true if the value in the item in the row indicated by the
+    given \a source_row and \a source_parent should be included in the
+    model.
+
+    The default implementation uses filterRegExp with the data
+    returned for the Qt::DisplayRole to determine if the row should be
+    accepted or not.
+
+    \sa filterAcceptsColumn()
 */
 bool QSortFilterProxyModel::filterAcceptsRow(int source_row, const QModelIndex &source_parent) const
 {
@@ -857,15 +1083,20 @@ bool QSortFilterProxyModel::filterAcceptsRow(int source_row, const QModelIndex &
     if (d->filter_regexp.isEmpty() || d->filter_column == -1)
         return true;
     QModelIndex source_index = d->model->index(source_row, d->filter_column, source_parent);
-    Q_ASSERT(source_index.isValid());
+    if (!source_index.isValid()) // the column may not exist
+        return true;
     QString key = d->model->data(source_index, Qt::DisplayRole).toString();
     return key.contains(d->filter_regexp);
 }
 
 /*!
-  Returns true if the value in the item in the column indicated by
-  the given \a source_column and \a source_parent should be included in the model.
-  The default implementation returns true.
+    Returns true if the value in the item in the column indicated by
+    the given \a source_column and \a source_parent should be included
+    in the model.
+
+    The default implementation returns true.
+
+    \sa filterAcceptsRow()
 */
 bool QSortFilterProxyModel::filterAcceptsColumn(int source_column, const QModelIndex &source_parent) const
 {
@@ -875,8 +1106,10 @@ bool QSortFilterProxyModel::filterAcceptsColumn(int source_column, const QModelI
 }
 
 /*!
-  Returns the source model index  corresponding to the
-  given \a proxyIndex from the sorting filter  model.
+   Returns the source model index corresponding to the given \a
+   proxyIndex from the sorting filter model.
+
+   \sa mapFromSource()
 */
 QModelIndex QSortFilterProxyModel::mapToSource(const QModelIndex &proxyIndex) const
 {
@@ -885,8 +1118,10 @@ QModelIndex QSortFilterProxyModel::mapToSource(const QModelIndex &proxyIndex) co
 }
 
 /*!
-  Returns the model index in the QSortFilterProxyModel given
-  the \a sourceIndex from the source model.
+    Returns the model index in the QSortFilterProxyModel given the \a
+    sourceIndex from the source model.
+
+    \sa mapToSource()
 */
 QModelIndex QSortFilterProxyModel::mapFromSource(const QModelIndex &sourceIndex) const
 {
@@ -911,3 +1146,5 @@ QItemSelection QSortFilterProxyModel::mapSelectionFromSource(const QItemSelectio
 }
 
 #include "moc_qsortfilterproxymodel.cpp"
+
+#endif // QT_NO_SORTFILTERPROXYMODEL
