@@ -26,6 +26,8 @@
 
 #include <QtGui/qabstractitemview.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Gui)
 
 #ifndef QT_NO_TABLEVIEW
@@ -135,4 +137,6 @@ private:
 
 #endif // QT_NO_TABLEVIEW
 
+QT_END_HEADER
+
 #endif // QTABLEVIEW_H
