@@ -29,6 +29,8 @@
 #include <QtCore/qvariant.h>
 #include <QtCore/qvector.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Gui)
 
 #ifndef QT_NO_TREEWIDGET
@@ -291,15 +293,15 @@ private:
     Q_DECLARE_PRIVATE(QTreeWidget)
     Q_DISABLE_COPY(QTreeWidget)
 
-    Q_PRIVATE_SLOT(d_func(), void emitItemPressed(const QModelIndex &index))
-    Q_PRIVATE_SLOT(d_func(), void emitItemClicked(const QModelIndex &index))
-    Q_PRIVATE_SLOT(d_func(), void emitItemDoubleClicked(const QModelIndex &index))
-    Q_PRIVATE_SLOT(d_func(), void emitItemActivated(const QModelIndex &index))
-    Q_PRIVATE_SLOT(d_func(), void emitItemEntered(const QModelIndex &index))
-    Q_PRIVATE_SLOT(d_func(), void emitItemChanged(const QModelIndex &index))
-    Q_PRIVATE_SLOT(d_func(), void emitItemExpanded(const QModelIndex &index))
-    Q_PRIVATE_SLOT(d_func(), void emitItemCollapsed(const QModelIndex &index))
-    Q_PRIVATE_SLOT(d_func(), void emitCurrentItemChanged(const QModelIndex &previous, const QModelIndex &current))
+    Q_PRIVATE_SLOT(d_func(), void _q_emitItemPressed(const QModelIndex &index))
+    Q_PRIVATE_SLOT(d_func(), void _q_emitItemClicked(const QModelIndex &index))
+    Q_PRIVATE_SLOT(d_func(), void _q_emitItemDoubleClicked(const QModelIndex &index))
+    Q_PRIVATE_SLOT(d_func(), void _q_emitItemActivated(const QModelIndex &index))
+    Q_PRIVATE_SLOT(d_func(), void _q_emitItemEntered(const QModelIndex &index))
+    Q_PRIVATE_SLOT(d_func(), void _q_emitItemChanged(const QModelIndex &index))
+    Q_PRIVATE_SLOT(d_func(), void _q_emitItemExpanded(const QModelIndex &index))
+    Q_PRIVATE_SLOT(d_func(), void _q_emitItemCollapsed(const QModelIndex &index))
+    Q_PRIVATE_SLOT(d_func(), void _q_emitCurrentItemChanged(const QModelIndex &previous, const QModelIndex &current))
 
 };
 
@@ -308,4 +310,6 @@ inline QTreeWidgetItem *QTreeWidget::itemAt(int ax, int ay) const
 
 #endif // QT_NO_TREEWIDGET
 
+QT_END_HEADER
+
 #endif // QTREEWIDGET_H
