@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
@@ -53,7 +53,7 @@ static QString qt_strippedText(QString s)
 
 
 QActionPrivate::QActionPrivate() : group(0), enabled(1), forceDisabled(0),
-                                   visible(1), forceInvisible(0), checkable(0), checked(0), separator(0)
+                                   visible(1), forceInvisible(0), checkable(0), checked(0), separator(0), fontSet(false)
 {
 #ifdef QT3_SUPPORT
     static int qt_static_action_id = -1;
@@ -109,7 +109,6 @@ void QActionPrivate::setShortcutEnabled(bool enable, QShortcutMap &map)
     \brief The QAction class provides an abstract user interface
     action that can be inserted into widgets.
 
-    \ingroup basic
     \ingroup application
     \mainclass
 
@@ -135,7 +134,7 @@ void QActionPrivate::setShortcutEnabled(bool enable, QShortcutMap &map)
     use as menu items.
 
     A QAction may contain an icon, menu text, a shortcut, status text,
-    "What's This?" text, and a tool tip. Most of these can be set in
+    "What's This?" text, and a tooltip. Most of these can be set in
     the constructor. They can also be set independently with
     setIcon(), setText(), setIconText(), setShortcut(),
     setStatusTip(), setWhatsThis(), and setToolTip(). For menu items,
@@ -195,7 +194,7 @@ QAction::QAction(QObject* parent)
     Option..." becomes "Menu Option") as descriptive text for
     toolbuttons. You can override this by setting a specific
     description with setText(). The same text will be used for
-    tool tips unless you specify a different test using
+    tooltips unless you specify a different test using
     setToolTip().
 
 */
@@ -218,7 +217,7 @@ QAction::QAction(const QString &text, QObject* parent)
     Option..." becomes "Menu Option") as descriptive text for
     toolbuttons. You can override this by setting a specific
     description with setText(). The same text will be used for
-    tool tips unless you specify a different test using
+    tooltips unless you specify a different test using
     setToolTip().
 */
 QAction::QAction(const QIcon &icon, const QString &text, QObject* parent)
@@ -309,6 +308,7 @@ void QAction::setFont(const QFont &font)
     if (d->font == font)
         return;
 
+    d->fontSet = true;
     d->font = font;
     d->sendDataChanged();
 }
@@ -543,14 +543,20 @@ QString QAction::text() const
     \property QAction::iconText
     \brief the action's descriptive icon text
 
-    If QMainWindow::usesTextLabel is true, the text appears as a label
-    in the relevant tool button. It also serves as the default text in
-    menus and tool tips if these have not been specifically defined
-    with setText() or setToolTip(). If the icon text is not explicitly
-    set in the by using setIconText(), the action's normal text will
-    be used as icon text. There is no default icon text.
+    If QToolBar::toolButtonStyle is set to a value that permits text to
+    be displayed, the text defined held in this property appears as a
+    label in the relevant tool button.
 
-    \sa setToolTip() setStatusTip()
+    It also serves as the default text in menus and tooltips if the action
+    has not been defined with setText() or setToolTip(), and will
+    also be used in toolbar buttons if no icon has been defined using setIcon().
+
+    If the icon text is not explicitly set, the action's normal text will be
+    used for the icon text.
+
+    There is no default icon text.
+
+    \sa setToolTip(), setStatusTip()
 */
 void QAction::setIconText(const QString &text)
 {
@@ -574,12 +580,10 @@ QString QAction::iconText() const
 
 /*!
     \property QAction::toolTip
-    \brief the action's tool tip
+    \brief the action's tooltip
 
-    This text is used for the tool tip. If no status tip has been set
-    the tool tip will be used for the status tip.
-
-    If no tool tip is specified the action's text is used.
+    This text is used for the tooltip. If no tooltip is specified,
+    the action's text is used.
 
     \sa setStatusTip() setShortcut()
 */
@@ -608,11 +612,9 @@ QString QAction::toolTip() const
     \property QAction::statusTip
     \brief the action's status tip
 
-    The statusTip is displayed on all status bars provided by the
+    The status tip is displayed on all status bars provided by the
     action's top-level parent widget.
 
-    There is no default statusTip text.
-
     \sa setToolTip() showStatusText()
 */
 void QAction::setStatusTip(const QString &statustip)
@@ -721,13 +723,11 @@ void QAction::setChecked(bool b)
     if (!d->checkable || d->checked == b)
         return;
 
-    QObject *guard = this;
-    QMetaObject::addGuard(&guard);
+    QPointer<QAction> guard(this);
     d->checked = b;
     d->sendDataChanged();
     if (guard)
         emit toggled(b);
-    QMetaObject::removeGuard(&guard);
 }
 
 bool QAction::isChecked() const
