@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
@@ -98,7 +98,7 @@
 
     The problem of obtaining the window IDs is often solved by the
     container invoking the application that provides the widget as a
-    seperate process (as a panel invokes a docked applet), passing
+    separate process (as a panel invokes a docked applet), passing
     its window ID to the new process as a command-line argument. The
     new process can then call embedInto() with the container's window
     ID, as shown in the example code above. Similarily, the new
@@ -217,6 +217,12 @@
     closes.
 */
 
+/*!
+    \fn QX11EmbedWidget::Error QX11EmbedWidget::error() const
+
+    Returns the last error that occurred.
+*/
+
 /*!
     \fn void QX11EmbedWidget::error(QX11EmbedWidget::Error error)
 
@@ -1539,8 +1545,6 @@ void QX11EmbedContainerPrivate::acceptClient(WId window)
     unsigned long nitems_return = 0;
     unsigned long bytes_after_return;
     unsigned char *prop_return = 0;
-    bool useXEmbedInfo = false;
-    unsigned int clientflags = 0;
     unsigned int clientversion = 0;
 
     // Add this client to our saveset, so if we crash, the client window
@@ -1560,11 +1564,8 @@ void QX11EmbedContainerPrivate::acceptClient(WId window)
 	    clientIsXEmbed = true;
 
 	    unsigned int *p = (unsigned int *)prop_return;
-	    if (nitems_return >= 2) {
+	    if (nitems_return >= 2)
 		clientversion = p[0];
-		clientflags = p[1];
-		useXEmbedInfo = true;
-	    }
 	}
 
 	XFree(prop_return);
