@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
@@ -28,6 +28,8 @@
 #include <QtCore/qobjectdefs.h>
 #include <QtGui/qpainter.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Gui)
 
 class QFontEngine;
@@ -299,4 +301,6 @@ Q_DECLARE_OPERATORS_FOR_FLAGS(QTextItem::RenderFlags)
 Q_DECLARE_OPERATORS_FOR_FLAGS(QPaintEngine::PaintEngineFeatures)
 Q_DECLARE_OPERATORS_FOR_FLAGS(QPaintEngine::DirtyFlags)
 
+QT_END_HEADER
+
 #endif // QPAINTENGINE_H
