@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
@@ -276,8 +276,10 @@ public:
         if (closePolygon && clipped->size() > 0) {
             // close clipped polygon
             if (clipped->at(0).x != clipped->at(clipped->size()-1).x ||
-                clipped->at(0).y != clipped->at(clipped->size()-1).y)
-                clipped->add(clipped->at(0));
+                clipped->at(0).y != clipped->at(clipped->size()-1).y) {
+                OutType ot = clipped->at(0);
+                clipped->add(ot);
+            }
         }
         *outCount = clipped->size();
         *outPoints = clipped->data();
