@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
@@ -69,7 +69,7 @@ void QPrinterPrivate::createDefaultEngines()
         printEngine = psEngine;
 #endif
     } else {
-        QPdfEngine *pdfEngine = new QPdfEngine;
+        QPdfEngine *pdfEngine = new QPdfEngine(printerMode);
         paintEngine = pdfEngine;
         printEngine = pdfEngine;
     }
@@ -79,7 +79,7 @@ void QPrinterPrivate::createDefaultEngines()
 
 
 /*!
-  \class QPrinter qprinter.h
+  \class QPrinter
   \brief The QPrinter class is a paint device that paints on a printer.
 
   \ingroup multimedia
@@ -108,7 +108,7 @@ void QPrinterPrivate::createDefaultEngines()
   default is false, so that by default you should be able to paint
   on (0,0). If true the origin of the coordinate system will be in
   the top left corner of the paper and most probably the printer
-  will not be able to paint something there due to it's physical
+  will not be able to paint something there due to its physical
   margins.
   \i setNumCopies() tells QPrinter how many copies of the document
   it should print.
@@ -131,34 +131,6 @@ void QPrinterPrivate::createDefaultEngines()
   If your current locale converts "," to ".", you will need to set
   a locale that doesn't do this (e.g. the "C" locale) before using
   QPrinter.
-
-  The TrueType font embedding for Qt's postscript driver uses code
-  by David Chappell of Trinity College Computing Center.
-
-  \legalese
-  Copyright 1995, Trinity College Computing Center. \BR
-  Written by David Chappell.
-
-  Permission to use, copy, modify, and distribute this software and
-  its documentation for any purpose and without fee is hereby
-  granted, provided that the above copyright notice appear in all
-  copies and that both that copyright notice and this permission
-  notice appear in supporting documentation. This software is
-  provided "as is" without express or implied warranty.
-
-  TrueType font support. These functions allow PPR to generate
-  PostScript fonts from Microsoft compatible TrueType font files.
-
-  The functions in this file do most of the work to convert a
-  TrueType font to a type 3 PostScript font.
-
-  Most of the material in this file is derived from a program called
-  "ttf2ps" which L. S. Ng posted to the usenet news group
-  "comp.sources.postscript". The author did not provide a copyright
-  notice or indicate any restrictions on use.
-
-  Last revised 11 July 1995.
-  \endlegalese
 */
 
 /*!
@@ -266,7 +238,7 @@ void QPrinterPrivate::createDefaultEngines()
   \value B8 64 x 91 mm
   \value B9 45 x 64 mm
   \value C5E 163 x 229 mm
-  \value Comm10E 105 x 241 mm, US Common 10 Envelope
+  \value Comm10E 105 x 241 mm, U.S. Common 10 Envelope
   \value DLE 110 x 220 mm
   \value Executive 7.5 x 10 inches, 191 x 254 mm
   \value Folio 210 x 330 mm
@@ -274,11 +246,12 @@ void QPrinterPrivate::createDefaultEngines()
   \value Legal 8.5 x 14 inches, 216 x 356 mm
   \value Letter 8.5 x 11 inches, 216 x 279 mm
   \value Tabloid 279 x 432 mm
-  \value Custom
-  \omitvalue NPageSize
+  \value Custom Unknown size
 
   With setFullPage(false) (the default), the metrics will be a bit
   smaller; how much depends on the printer in use.
+
+  \omitvalue NPageSize
 */
 
 
@@ -365,7 +338,7 @@ void QPrinterPrivate::createDefaultEngines()
 */
 QPrinter::QPrinter(PrinterMode mode)
     : QPaintDevice(),
-      d_ptr(new QPrinterPrivate)
+      d_ptr(new QPrinterPrivate(this))
 {
     if (!qApp) {
         qFatal("QPrinter: Must construct a QApplication before a QPaintDevice");
@@ -412,9 +385,6 @@ void QPrinter::setEngines(QPrintEngine *printEngine, QPaintEngine *paintEngine)
 QPrinter::~QPrinter()
 {
     Q_D(QPrinter);
-#if defined(QT3_SUPPORT) && !(defined(QT_NO_PRINTDIALOG))
-    delete d->printDialog;
-#endif
     if (d->use_default_engine)
         delete d->printEngine;
     delete d;
@@ -431,7 +401,7 @@ QPrinter::~QPrinter()
     traditionally done in Qt. This mode is the default.
 
     \value PdfFormat QPrinter will generate its output as a PDF file.
-    PDF files generated by Qt are not searchable.
+    As of Qt 4.1.3 PDF files generated by Qt are searchable on all platforms.
 */
 
 /*!
@@ -1300,11 +1270,12 @@ void QPrinter::setPrinterSelectionOption(const QString &option)
 
 int QPrinter::fromPage() const
 {
-#if defined(QT3_SUPPORT) && !defined(QT_NO_PRINTDIALOG)
+#if !defined(QT_NO_PRINTDIALOG)
     Q_D(const QPrinter);
-    if (!d->printDialog)
-        const_cast<QPrinter*>(this)->d_func()->printDialog = new QPrintDialog(const_cast<QPrinter*>(this));
-    return const_cast<QPrinter*>(this)->d_func()->printDialog->fromPage();
+    if (d->outputFormat == QPrinter::PdfFormat)
+        return 0;
+    d->ensurePrintDialog();
+    return d->printDialog->fromPage();
 #else
     return 0;
 #endif
@@ -1326,11 +1297,13 @@ int QPrinter::fromPage() const
 
 int QPrinter::toPage() const
 {
-#if defined(QT3_SUPPORT) && !defined(QT_NO_PRINTDIALOG)
+#if !defined(QT_NO_PRINTDIALOG)
     Q_D(const QPrinter);
-    if (!d->printDialog)
-        const_cast<QPrinter*>(this)->d_func()->printDialog = new QPrintDialog(const_cast<QPrinter*>(this));
-    return const_cast<QPrinter*>(this)->d_func()->printDialog->toPage();
+    if (d->outputFormat == QPrinter::PdfFormat)
+        return 0;
+
+    d->ensurePrintDialog();
+    return d->printDialog->toPage();
 #else
     return 0;
 #endif
@@ -1355,10 +1328,11 @@ int QPrinter::toPage() const
 
 void QPrinter::setFromTo(int from, int to)
 {
-#if defined(QT3_SUPPORT) && !defined(QT_NO_PRINTDIALOG)
+#if !defined(QT_NO_PRINTDIALOG)
     Q_D(QPrinter);
-    if (!d->printDialog)
-        const_cast<QPrinter*>(this)->d_func()->printDialog = new QPrintDialog(const_cast<QPrinter*>(this));
+    if (d->outputFormat == QPrinter::PdfFormat)
+        return;
+    d->ensurePrintDialog();
     d->printDialog->setFromTo(from, to);
 #else
     Q_UNUSED(from);
@@ -1378,12 +1352,12 @@ void QPrinter::setOutputToFile(bool f)
     }
 }
 
-bool qt_compat_QPrinter_printSetup(QPrinter *p, QPrinterPrivate *pd, QWidget *parent)
+bool qt_compat_QPrinter_printSetup(QPrinter *, QPrinterPrivate *pd, QWidget *parent)
 {
-    if (!pd->printDialog)
-        pd->printDialog = new QPrintDialog(p, parent);
-    else if (parent)
-        pd->printDialog->setParent(parent);
+    pd->ensurePrintDialog();
+
+    if (parent)
+        pd->printDialog->setParent(parent, pd->printDialog->windowFlags());
 
     return pd->printDialog->exec() != 0;
 }
@@ -1446,9 +1420,8 @@ bool QPrinter::setup(QWidget *parent)
 int QPrinter::minPage() const
 {
     Q_D(const QPrinter);
-    if (!d->printDialog)
-        const_cast<QPrinter*>(this)->d_func()->printDialog = new QPrintDialog(const_cast<QPrinter*>(this));
-    return const_cast<QPrinter*>(this)->d_func()->printDialog->minPage();
+    d->ensurePrintDialog();
+    return d->printDialog->minPage();
 }
 
 /*!
@@ -1457,9 +1430,8 @@ int QPrinter::minPage() const
 int QPrinter::maxPage() const
 {
     Q_D(const QPrinter);
-    if (!d->printDialog)
-        const_cast<QPrinter*>(this)->d_func()->printDialog = new QPrintDialog(const_cast<QPrinter*>(this));
-    return const_cast<QPrinter *>(this)->d_func()->printDialog->maxPage();
+    d->ensurePrintDialog();
+    return d_func()->printDialog->maxPage();
 }
 
 /*!
@@ -1468,8 +1440,7 @@ int QPrinter::maxPage() const
 void QPrinter::setMinMax( int minPage, int maxPage )
 {
     Q_D(QPrinter);
-    if (!d->printDialog)
-        const_cast<QPrinter*>(this)->d_func()->printDialog = new QPrintDialog(const_cast<QPrinter*>(this));
+    d->ensurePrintDialog();
     d->printDialog->setMinMax(minPage, maxPage);
 }
 
@@ -1485,9 +1456,8 @@ void QPrinter::setMinMax( int minPage, int maxPage )
 bool QPrinter::collateCopiesEnabled() const
 {
     Q_D(const QPrinter);
-    if (!d->printDialog)
-        const_cast<QPrinter*>(this)->d_func()->printDialog = new QPrintDialog(const_cast<QPrinter*>(this));
-    return const_cast<QPrinter*>(this)->d_func()->printDialog->isOptionEnabled(QPrintDialog::PrintCollateCopies);
+    d->ensurePrintDialog();
+    return d->printDialog->isOptionEnabled(QPrintDialog::PrintCollateCopies);
 }
 
 /*!
@@ -1499,9 +1469,8 @@ bool QPrinter::collateCopiesEnabled() const
 void QPrinter::setCollateCopiesEnabled(bool enable)
 {
     Q_D(QPrinter);
-    if (!d->printDialog)
-        const_cast<QPrinter*>(this)->d_func()->printDialog = new QPrintDialog(const_cast<QPrinter*>(this));
 
+    d->ensurePrintDialog();
     QPrintDialog::PrintDialogOptions opt = d->printDialog->enabledOptions();
     if (enable)
         opt |= QPrintDialog::PrintCollateCopies;
@@ -1518,8 +1487,7 @@ void QPrinter::setCollateCopiesEnabled(bool enable)
 void QPrinter::setPrintRange( PrintRange range )
 {
     Q_D(QPrinter);
-    if (!d->printDialog)
-        const_cast<QPrinter*>(this)->d_func()->printDialog = new QPrintDialog(const_cast<QPrinter*>(this));
+    d->ensurePrintDialog();
     d->printDialog->setPrintRange(QPrintDialog::PrintRange(range));
 }
 
@@ -1535,9 +1503,8 @@ void QPrinter::setPrintRange( PrintRange range )
 QPrinter::PrintRange QPrinter::printRange() const
 {
     Q_D(const QPrinter);
-    if (!d->printDialog)
-        const_cast<QPrinter*>(this)->d_func()->printDialog = new QPrintDialog(const_cast<QPrinter*>(this));
-    return PrintRange(const_cast<QPrinter*>(this)->d_func()->printDialog->printRange());
+    d->ensurePrintDialog();
+    return PrintRange(d->printDialog->printRange());
 }
 
 /*!
@@ -1546,8 +1513,7 @@ QPrinter::PrintRange QPrinter::printRange() const
 void QPrinter::setOptionEnabled( PrinterOption option, bool enable )
 {
     Q_D(QPrinter);
-    if (!d->printDialog)
-        const_cast<QPrinter*>(this)->d_func()->printDialog = new QPrintDialog(const_cast<QPrinter*>(this));
+    d->ensurePrintDialog();
     QPrintDialog::PrintDialogOptions opt = d->printDialog->enabledOptions();
     if (enable)
         opt |= QPrintDialog::PrintDialogOption(1 << option);
@@ -1562,15 +1528,16 @@ void QPrinter::setOptionEnabled( PrinterOption option, bool enable )
 bool QPrinter::isOptionEnabled( PrinterOption option ) const
 {
     Q_D(const QPrinter);
-    if (!d->printDialog)
-        const_cast<QPrinter*>(this)->d_func()->printDialog = new QPrintDialog(const_cast<QPrinter*>(this));
-    return const_cast<QPrinter*>(this)->d_func()->printDialog->isOptionEnabled(QPrintDialog::PrintDialogOption(option));
+
+    d->ensurePrintDialog();
+    return d->printDialog->isOptionEnabled(QPrintDialog::PrintDialogOption(option));
 }
 
 #endif // QT3_SUPPORT
 
 /*!
     \class QPrintEngine
+    \ingroup multimedia
 
     \brief The QPrintEngine class defines an interface for how QPrinter
     interacts with a given printing subsystem.
