@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
@@ -41,38 +41,57 @@
 #ifndef QT_NO_PRINTER
 
 #include "QtGui/qprinter.h"
-#ifdef QT3_SUPPORT
-#include "QtCore/qpointer.h"
 #include "QtGui/qprintdialog.h"
-#endif
+#include "QtCore/qpointer.h"
 
 class QPrintEngine;
 
 class QPrinterPrivate
 {
+    Q_DECLARE_PUBLIC(QPrinter)
 public:
-    QPrinterPrivate()
+    QPrinterPrivate(QPrinter *printer)
         : printEngine(0)
         , paintEngine(0)
-#if defined(QT3_SUPPORT) && !(defined(QT_NO_PRINTDIALOG))
+        , q_ptr(printer)
+#if !(defined(QT_NO_PRINTDIALOG))
+        , ownPrintDialog(0)
         , printDialog(0)
 #endif
         , use_default_engine(true)
     {
     }
 
+    ~QPrinterPrivate() {
+#if !(defined(QT_NO_PRINTDIALOG))
+        delete ownPrintDialog;
+        ownPrintDialog = 0;
+#endif
+    }
+
     void createDefaultEngines();
 
     QPrinter::PrinterMode printerMode;
     QPrinter::OutputFormat outputFormat;
     QPrintEngine *printEngine;
     QPaintEngine *paintEngine;
+    QPrinter *q_ptr;
 
-#if defined(QT3_SUPPORT) && !(defined(QT_NO_PRINTDIALOG))
-    QPointer<QPrintDialog> printDialog;
+#if !(defined(QT_NO_PRINTDIALOG))
+    mutable QPrintDialog *ownPrintDialog;
+    mutable QPointer<QAbstractPrintDialog> printDialog;
 #endif
 
     bool use_default_engine;
+#ifndef QT_NO_PRINTDIALOG
+    void ensurePrintDialog() const {
+        if (printDialog)
+            return;
+        if (!ownPrintDialog) {
+            ownPrintDialog = new QPrintDialog(q_ptr); // printDialog is set here.
+        }
+    }
+#endif
 };
 
 #endif // QT_NO_PRINTER
