@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
@@ -142,10 +142,13 @@ void QCDEStyle::drawControl(ControlElement element, const QStyleOption *opt, QPa
         QCommonStyle::drawControl(element, opt, p, widget);
         break; }
     case CE_RubberBand: {
+        p->save();
+        p->setClipping(false);
         QPainterPath path;
         path.addRect(opt->rect);
         path.addRect(opt->rect.adjusted(2, 2, -2, -2));
         p->fillPath(path, opt->palette.dark());
+        p->restore();
         break; }
     default:
         QMotifStyle::drawControl(element, opt, p, widget);
@@ -166,13 +169,13 @@ void QCDEStyle::drawPrimitive(PrimitiveElement pe, const QStyleOption *opt, QPai
         bool down = opt->state & State_Sunken;
         bool on = opt->state & State_On;
         bool showUp = !(down ^ on);
-        QBrush fill = showUp || opt->state & State_NoChange ? opt->palette.brush(QPalette::Button) : opt->palette.brush(QPalette::Mid);
+        QBrush fill = (showUp || (opt->state & State_NoChange)) ? opt->palette.brush(QPalette::Button) : opt->palette.brush(QPalette::Mid);
         qDrawShadePanel(p, opt->rect, opt->palette, !showUp, pixelMetric(PM_DefaultFrameWidth), &opt->palette.brush(QPalette::Button));
 
-        if (on) {
+        if (on || (opt->state & State_NoChange)) {
             QRect r = opt->rect;
             QPolygon a(7 * 2);
-            int i, xx, yy;           
+            int i, xx, yy;
             xx = r.x() + 3;
             yy = r.y() + 5;
             if (opt->rect.width() <= 9) {
