@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
@@ -32,6 +32,8 @@
 #include <QtCore/qlist.h>
 #endif
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Gui)
 
 class QStringList;
@@ -129,4 +131,6 @@ private:
     QFontDatabasePrivate *d;
 };
 
+QT_END_HEADER
+
 #endif // QFONTDATABASE_H
