@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
@@ -93,8 +93,8 @@ public:
         : currentPage(0)
     {
     }
-    void buttonClicked();
-    void widgetDestroyed(QObject*);
+    void _q_buttonClicked();
+    void _q_widgetDestroyed(QObject*);
 
     Page *page(QWidget *widget) const;
     const Page *page(int index) const;
@@ -357,12 +357,12 @@ int QToolBox::insertItem(int index, QWidget *widget, const QIcon &icon, const QS
         return -1;
 
     Q_D(QToolBox);
-    connect(widget, SIGNAL(destroyed(QObject*)), this, SLOT(widgetDestroyed(QObject*)));
+    connect(widget, SIGNAL(destroyed(QObject*)), this, SLOT(_q_widgetDestroyed(QObject*)));
 
     QToolBoxPrivate::Page c;
     c.widget = widget;
     c.button = new QToolBoxButton(this);
-    connect(c.button, SIGNAL(clicked()), this, SLOT(buttonClicked()));
+    connect(c.button, SIGNAL(clicked()), this, SLOT(_q_buttonClicked()));
 
     c.sv = new QScrollArea(this);
     c.sv->setWidget(widget);
@@ -400,7 +400,7 @@ int QToolBox::insertItem(int index, QWidget *widget, const QIcon &icon, const QS
     return index;
 }
 
-void QToolBoxPrivate::buttonClicked()
+void QToolBoxPrivate::_q_buttonClicked()
 {
     Q_Q(QToolBox);
     QToolBoxButton *tb = ::qobject_cast<QToolBoxButton*>(q->sender());
@@ -454,7 +454,7 @@ void QToolBoxPrivate::relayout()
     }
 }
 
-void QToolBoxPrivate::widgetDestroyed(QObject *object)
+void QToolBoxPrivate::_q_widgetDestroyed(QObject *object)
 {
     Q_Q(QToolBox);
     // no verification - vtbl corrupted already
@@ -490,10 +490,10 @@ void QToolBox::removeItem(int index)
 {
     Q_D(QToolBox);
     if (QWidget *w = widget(index)) {
-        disconnect(w, SIGNAL(destroyed(QObject*)), this, SLOT(widgetDestroyed(QObject*)));
+        disconnect(w, SIGNAL(destroyed(QObject*)), this, SLOT(_q_widgetDestroyed(QObject*)));
         w->setParent(this);
         // destroy internal data
-        d->widgetDestroyed(w);
+        d->_q_widgetDestroyed(w);
         itemRemoved(index);
     }
 }
