@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the QtNetwork module of the Qt Toolkit.
 **
@@ -541,9 +541,9 @@ bool QFtpDTP::parseDir(const QString &buffer, const QString &userName, QUrlInfo
     if (lst[7].contains(":")) {
         // if the year-field is missing, check the modification date/time of
         // the file and compare to "now". If the file was changed in the
-        // "future", also considering a possible 13 hour time zone gap, then
+        // "future", also considering a possible 24 hour time zone gap, then
         // we assume it was changed a year ago.
-        const int futureTolerance = 46800;
+        const int futureTolerance = 86400;
         if(info->lastModified().secsTo(QDateTime::currentDateTime()) < -futureTolerance) {
             QDateTime dt = info->lastModified();
             QDate d = dt.date();
@@ -628,7 +628,8 @@ void QFtpDTP::socketReadyRead()
             qDebug("QFtpDTP read: %lli bytes (total %lli bytes)", bytesRead, bytesDone);
 #endif
             emit dataTransferProgress(bytesDone, bytesTotal);
-            data.dev->write(ba);
+            if (data.dev)       // make sure it wasn't deleted in the slot
+                data.dev->write(ba);
         } else {
 #if defined(QFTPDTP_DEBUG)
             qDebug("QFtpDTP readyRead: %lli bytes available (total %lli bytes read)",
@@ -1164,11 +1165,11 @@ public:
     ~QFtpPrivate() { while (!pending.isEmpty()) delete pending.takeFirst(); }
 
     // private slots
-    void startNextCommand();
-    void piFinished(const QString&);
-    void piError(int, const QString&);
-    void piConnectState(int);
-    void piFtpReply(int, const QString&);
+    void _q_startNextCommand();
+    void _q_piFinished(const QString&);
+    void _q_piError(int, const QString&);
+    void _q_piConnectState(int);
+    void _q_piFtpReply(int, const QString&);
 
     int addCommand(QFtpCommand *cmd);
 
@@ -1192,7 +1193,7 @@ int QFtpPrivate::addCommand(QFtpCommand *cmd)
 
     if (pending.count() == 1) {
         // don't emit the commandStarted() signal before the ID is returned
-        QTimer::singleShot(0, q_func(), SLOT(startNextCommand()));
+        QTimer::singleShot(0, q_func(), SLOT(_q_startNextCommand()));
     }
     return cmd->id;
 }
@@ -1359,13 +1360,13 @@ QFtp::QFtp(QObject *parent)
     d->errorString = tr("Unknown error");
 
     connect(&d->pi, SIGNAL(connectState(int)),
-            SLOT(piConnectState(int)));
+            SLOT(_q_piConnectState(int)));
     connect(&d->pi, SIGNAL(finished(QString)),
-            SLOT(piFinished(QString)));
+            SLOT(_q_piFinished(QString)));
     connect(&d->pi, SIGNAL(error(int,QString)),
-            SLOT(piError(int,QString)));
+            SLOT(_q_piError(int,QString)));
     connect(&d->pi, SIGNAL(rawFtpReply(int,QString)),
-            SLOT(piFtpReply(int,QString)));
+            SLOT(_q_piFtpReply(int,QString)));
 
     connect(&d->pi.dtp, SIGNAL(readyRead()),
             SIGNAL(readyRead()));
@@ -1388,13 +1389,13 @@ QFtp::QFtp(QObject *parent, const char *name)
     d->errorString = tr("Unknown error");
 
     connect(&d->pi, SIGNAL(connectState(int)),
-            SLOT(piConnectState(int)));
+            SLOT(_q_piConnectState(int)));
     connect(&d->pi, SIGNAL(finished(QString)),
-            SLOT(piFinished(QString)));
+            SLOT(_q_piFinished(QString)));
     connect(&d->pi, SIGNAL(error(int,QString)),
-            SLOT(piError(int,QString)));
+            SLOT(_q_piError(int,QString)));
     connect(&d->pi, SIGNAL(rawFtpReply(int,QString)),
-            SLOT(piFtpReply(int,QString)));
+            SLOT(_q_piFtpReply(int,QString)));
 
     connect(&d->pi.dtp, SIGNAL(readyRead()),
             SIGNAL(readyRead()));
@@ -2159,7 +2160,7 @@ QString QFtp::errorString() const
 
 /*! \internal
 */
-void QFtpPrivate::startNextCommand()
+void QFtpPrivate::_q_startNextCommand()
 {
     Q_Q(QFtp);
     if (pending.isEmpty())
@@ -2185,12 +2186,12 @@ void QFtpPrivate::startNextCommand()
     }
 
     if (c->command == QFtp::SetTransferMode) {
-        piFinished("Transfer mode set");
+        _q_piFinished("Transfer mode set");
     } else if (c->command == QFtp::SetProxy) {
         proxyHost = c->rawCmds[0];
         proxyPort = c->rawCmds[1].toUInt();
         c->rawCmds.clear();
-        piFinished("Proxy set to " + proxyHost + ":" + QString::number(proxyPort));
+        _q_piFinished("Proxy set to " + proxyHost + ":" + QString::number(proxyPort));
     } else if (c->command == QFtp::ConnectToHost) {
         if (!proxyHost.isEmpty()) {
             host = c->rawCmds[0];
@@ -2225,7 +2226,7 @@ void QFtpPrivate::startNextCommand()
 
 /*! \internal
 */
-void QFtpPrivate::piFinished(const QString&)
+void QFtpPrivate::_q_piFinished(const QString&)
 {
     if (pending.isEmpty())
         return;
@@ -2249,13 +2250,13 @@ void QFtpPrivate::piFinished(const QString&)
     if (pending.isEmpty()) {
         emit q_func()->done(false);
     } else {
-        startNextCommand();
+        _q_startNextCommand();
     }
 }
 
 /*! \internal
 */
-void QFtpPrivate::piError(int errorCode, const QString &text)
+void QFtpPrivate::_q_piError(int errorCode, const QString &text)
 {
     Q_Q(QFtp);
     QFtpCommand *c = pending.first();
@@ -2320,24 +2321,24 @@ void QFtpPrivate::piError(int errorCode, const QString &text)
     if (pending.isEmpty())
         emit q->done(true);
     else
-        startNextCommand();
+        _q_startNextCommand();
 }
 
 /*! \internal
 */
-void QFtpPrivate::piConnectState(int connectState)
+void QFtpPrivate::_q_piConnectState(int connectState)
 {
     state = QFtp::State(connectState);
     emit q_func()->stateChanged(state);
     if (close_waitForStateChange) {
         close_waitForStateChange = false;
-        piFinished(QT_TRANSLATE_NOOP("QFtp", "Connection closed"));
+        _q_piFinished(QT_TRANSLATE_NOOP("QFtp", "Connection closed"));
     }
 }
 
 /*! \internal
 */
-void QFtpPrivate::piFtpReply(int code, const QString &text)
+void QFtpPrivate::_q_piFtpReply(int code, const QString &text)
 {
     if (q_func()->currentCommand() == QFtp::RawCommand) {
         pi.rawCommand = true;
