@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the plugins of the Qt Toolkit.
 **
@@ -52,7 +52,7 @@
 #include <QtCore/qtextcodec.h>
 #include <QtCore/qlist.h>
 
-#ifndef QT_NO_TEXTCODECPLUGIN
+#ifndef QT_NO_TEXTCODEC
 
 class QEucKrCodec : public QTextCodec {
 public:
@@ -88,6 +88,6 @@ public:
 };
 #endif
 
-#endif // QT_NO_TEXTCODECPLUGIN
+#endif // QT_NO_TEXTCODEC
 
 #endif // QEUCKRCODEC_H
