@@ -27,6 +27,8 @@
 #include <QtCore/qobject.h>
 #include <QtGui/qkeysequence.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Qt3SupportLight)
 
 class Q3AccelPrivate;
@@ -81,4 +83,6 @@ private:
     friend class Q3AccelManager;
 };
 
+QT_END_HEADER
+
 #endif // Q3ACCEL_H
