@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the Qt3Support module of the Qt Toolkit.
 **
@@ -307,8 +307,9 @@ void Q3DragObject::dragLink()
     \value DragCopy        The data is copied.
     \value DragMove        The data is moved.
     \value DragLink        The data is linked.
-    \value DragCopyOrMove  The user chooses the mode by using a
-                           control key to switch from the default.
+    \value DragCopyOrMove  The user chooses the mode by using the
+                           \key{Shift} key to switch from the default
+                           copy mode to move mode.
 */
 
 
@@ -543,7 +544,7 @@ static QTextCodec *codecForHTML(const QByteArray &ba)
 
     if (ba.size() > 1 && (((uchar)ba[0] == 0xfe && (uchar)ba[1] == 0xff)
                           || ((uchar)ba[0] == 0xff && (uchar)ba[1] == 0xfe))) {
-        mib = 1000; // utf16
+        mib = 1015; // utf16
     } else if (ba.size() > 2
                && (uchar)ba[0] == 0xef
                && (uchar)ba[1] == 0xbb
@@ -666,7 +667,7 @@ bool Q3TextDrag::decode(const QMimeSource* e, QString& str, QString& subtype)
                     payload = e->encodedData(mime);
                     if (payload.size()) {
                         int l;
-                        if (codec->mibEnum() != 1000) {
+                        if (codec->mibEnum() != 1015) {
                             // length is at NUL or payload.size()
                             l = 0;
                             while (l < (int)payload.size() && payload[l])
@@ -857,7 +858,7 @@ bool Q3ImageDrag::decode(const QMimeSource* e, QImage& img)
         return false;
 
     QByteArray payload;
-    QList<QByteArray> fileFormats = QImageReader::supportedImageFormats();    
+    QList<QByteArray> fileFormats = QImageReader::supportedImageFormats();
 
     // PNG is best of all
     // (this is a rather strange hack, but it works now)
