@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the Qt3Support module of the Qt Toolkit.
 **
@@ -26,6 +26,8 @@
 
 #include <Qt3Support/q3editorfactory.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Qt3Support)
 
 #ifndef QT_NO_SQL_EDIT_WIDGETS
@@ -49,4 +51,6 @@ private:
 
 #endif // QT_NO_SQL_EDIT_WIDGETS
 
+QT_END_HEADER
+
 #endif // Q3SQLEDITORFACTORY_H
