@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the Qt3Support module of the Qt Toolkit.
 **
@@ -26,6 +26,8 @@
 
 #include <Qt3Support/q3glist.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Qt3SupportLight)
 
 template<class type>
@@ -169,4 +171,6 @@ public:
 			      { Q3GListIterator::operator=(it); return *this; }
 };
 
+QT_END_HEADER
+
 #endif // Q3PTRLIST_H
