@@ -29,6 +29,8 @@
 #include <QtCore/qobject.h>
 #include <QtCore/qstring.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Qt3SupportLight)
 
 #ifndef QT_NO_ACTION
@@ -196,4 +198,6 @@ private:
 
 #endif // QT_NO_ACTION
 
+QT_END_HEADER
+
 #endif // Q3ACTION_H
