@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the Qt3Support module of the Qt Toolkit.
 **
@@ -173,6 +173,13 @@
     content size limit, the item at the other end of the list is
     deleted. The definition of "other end" is
     implementation-dependent.
+
+    \omitvalue NoInsert
+    \omitvalue InsertAtTop
+    \omitvalue InsertAtCurrent
+    \omitvalue InsertAtBottom
+    \omitvalue InsertAfterCurrent
+    \omitvalue InsertBeforeCurrent
 */
 
 
@@ -292,7 +299,7 @@
     cleared if this property is set to true for a 1.x Motif style
     combobox. To avoid this, use setEditable() before inserting any
     items. Also note that the 1.x version of Motif didn't have any
-    editable comboboxes, so the combobox will change it's appearance
+    editable comboboxes, so the combobox will change its appearance
     to a 2.0 style Motif combobox is it is set to be editable.
 */
 
@@ -312,7 +319,8 @@
     \property Q3ComboBox::sizeLimit
     \brief the maximum on-screen size of the combobox.
 
-    This is disregarded in Motif 1.x style. The default limit is ten
+    This property is ignored for both Motif 1.x style and non-editable
+    comboboxes in Mac style. The default limit is ten
     lines. If the number of items in the combobox is or grows larger
     than lines, a scrollbar is added.
 */
@@ -329,9 +337,14 @@ public:
     {
 	return Q3PopupMenu::itemHeight( index );
     }
-
 };
 
+static inline QString escapedComboString(const QString &str)
+{
+    QString stringToReturn = str;
+    return stringToReturn.replace('&', "&&");
+}
+
 class Q3ComboBoxPopupItem : public QMenuItem
 {
     Q3ListBoxItem *li;
@@ -647,7 +660,7 @@ void Q3ComboBox::insertStrList( const Q3StrList *list, int index )
 	if ( d->usingListBox() )
 	    d->listBox()->insertItem( QString::fromLatin1(tmp), index );
 	else
-	    d->popup()->insertItem( QString::fromLatin1(tmp), index, index );
+	    d->popup()->insertItem( escapedComboString(QString::fromLatin1(tmp)), index, index );
 	if ( index++ == d->current && d->current < count() ) {
 	    if ( d->ed ) {
 		d->ed->setText( text( d->current ) );
@@ -675,7 +688,7 @@ void Q3ComboBox::insertStringList( const QStringList &list, int index )
 	if ( d->usingListBox() )
 	    d->listBox()->insertItem( *it, index );
 	else
-	    d->popup()->insertItem( *it, index, index );
+	    d->popup()->insertItem( escapedComboString(*it), index, index );
 	if ( index++ == d->current && d->current < count() ) {
 	    if ( d->ed ) {
 		d->ed->setText( text( d->current ) );
@@ -722,7 +735,7 @@ void Q3ComboBox::insertStrList( const char **strings, int numStrings, int index)
 	if ( d->usingListBox() )
 	    d->listBox()->insertItem( QString::fromLatin1(strings[i]), index );
 	else
-	    d->popup()->insertItem( QString::fromLatin1(strings[i]), index, index );
+	    d->popup()->insertItem( escapedComboString(QString::fromLatin1(strings[i])), index, index );
 	i++;
 	if ( index++ == d->current && d->current < count()  ) {
 	    if ( d->ed ) {
@@ -751,7 +764,7 @@ void Q3ComboBox::insertItem( const QString &t, int index )
     if ( d->usingListBox() )
 	d->listBox()->insertItem( t, index );
     else
-	d->popup()->insertItem( t, index, index );
+	d->popup()->insertItem( escapedComboString(t), index, index );
     if ( index != cnt )
 	reIndex();
     if ( index == d->current && d->current < count()  ) {
@@ -809,7 +822,7 @@ void Q3ComboBox::insertItem( const QPixmap &pixmap, const QString& text, int ind
     if ( d->usingListBox() )
 	d->listBox()->insertItem( pixmap, text, index );
     else
-	d->popup()->insertItem( pixmap, text, index, index );
+	d->popup()->insertItem( pixmap, escapedComboString(text), index, index );
     if ( index != cnt )
 	reIndex();
     if ( index == d->current && d->current < count()  ) {
@@ -937,10 +950,13 @@ QString Q3ComboBox::text( int index ) const
 {
     if ( !checkIndex( "text", name(), count(), index ) )
 	return QString::null;
-    if ( d->usingListBox() )
+    if ( d->usingListBox() ) {
 	return d->listBox()->text( index );
-    else
-	return d->popup()->text( index );
+    } else {
+        QString retText = d->popup()->text(index);
+        retText.replace("&&", "&");
+	return retText;
+    }
 }
 
 /*!
@@ -1538,12 +1554,12 @@ void Q3ComboBox::popup()
 	    for(unsigned int i = 0; i < d->listBox()->count(); i++) {
 		Q3ListBoxItem *item = d->listBox()->item(i);
 		if(item->rtti() == Q3ListBoxText::RTTI) {
-		    d->popup()->insertItem(item->text(), i, i);
+		    d->popup()->insertItem(escapedComboString(item->text()), i, i);
 		} else if(item->rtti() == Q3ListBoxPixmap::RTTI) {
 		    if(item->pixmap())
-			d->popup()->insertItem(QIcon(*item->pixmap()), item->text(), i, i);
+			d->popup()->insertItem(QIcon(*item->pixmap()), escapedComboString(item->text()), i, i);
 		    else
-			d->popup()->insertItem(item->text(), i, i);
+			d->popup()->insertItem(escapedComboString(item->text()), i, i);
 		} else {
 		    d->popup()->insertItem(new Q3ComboBoxPopupItem(item), i, i);
 		}
@@ -1625,7 +1641,9 @@ void Q3ComboBox::popup()
 
 
 /*!
-  \reimp
+  Updates the widget mask.
+
+  \sa QWidget::setMask()
 */
 void Q3ComboBox::updateMask()
 {
@@ -2015,7 +2033,10 @@ void Q3ComboBox::returnPressed()
 }
 
 
-/*! \reimp
+/*!
+  Enables the combobox if \a enable is true; otherwise disables it.
+
+  \sa QWidget::enabled
 */
 
 void Q3ComboBox::setEnabled( bool enable )
@@ -2290,7 +2311,9 @@ void Q3ComboBox::setLineEdit( QLineEdit *edit )
 }
 
 /*!
-    \reimp
+  Hides the combobox.
+
+  \sa QWidget::hide()
 */
 void Q3ComboBox::hide()
 {
