@@ -31,6 +31,8 @@
 #include <QtSql/qsqlquery.h>
 #endif
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Sql)
 
 class QStringList;
@@ -109,4 +111,6 @@ private:
     Q_DISABLE_COPY(QSqlDriver)
 };
 
+QT_END_HEADER
+
 #endif // QSQLDRIVER_H
