@@ -28,6 +28,8 @@
 #include <QtCore/qstring.h>
 #include <QtCore/qlist.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Sql)
 
 class Q_SQL_EXPORT QSqlIndex : public QSqlRecord
@@ -63,4 +65,6 @@ private:
     QList<bool> sorts;
 };
 
+QT_END_HEADER
+
 #endif // QSQLINDEX_H
