@@ -27,6 +27,8 @@
 #include <QtCore/qabstractitemmodel.h>
 #include <QtSql/qsqldatabase.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Sql)
 
 class QSqlQueryModelPrivate;
@@ -76,4 +78,6 @@ protected:
     QSqlQueryModel(QSqlQueryModelPrivate &dd, QObject *parent = 0);
 };
 
+QT_END_HEADER
+
 #endif // QSQLQUERYMODEL_H
