@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the QtSql module of the Qt Toolkit.
 **
@@ -27,6 +27,8 @@
 #include <QtSql/qsqldatabase.h>
 #include <QtSql/qsqlquerymodel.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Sql)
 
 class QSqlTableModelPrivate;
@@ -112,4 +114,6 @@ protected:
     QModelIndex indexInQuery(const QModelIndex &item) const;
 };
 
+QT_END_HEADER
+
 #endif // QSQLTABLEMODEL_H
