@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the QtXML module of the Qt Toolkit.
 **
@@ -30,6 +30,8 @@
 #include <QtCore/qstringlist.h>
 #include <QtCore/qlist.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Xml)
 
 class QXmlNamespaceSupport;
@@ -393,4 +395,6 @@ private:
 inline int QXmlAttributes::count() const
 { return length(); }
 
+QT_END_HEADER
+
 #endif // QXML_H
