@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
@@ -31,6 +31,8 @@
 #include <QtCore/QHash>
 #include <QtCore/QPair>
 
+QT_BEGIN_HEADER
+
 class QExtensionManager;
 
 class QDESIGNER_EXTENSION_EXPORT QExtensionFactory : public QObject, public QAbstractExtensionFactory
@@ -54,4 +56,6 @@ private:
     mutable QHash<QObject*, bool> m_extended;
 };
 
+QT_END_HEADER
+
 #endif // DEFAULT_EXTENSIONFACTORY_H
