@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
@@ -37,6 +37,8 @@
 
 #include <QtCore/QVariant>
 #include <QtCore/QMap>
+#include <QtGui/QMainWindow>
+#include "abstractformwindow.h"
 
 namespace qdesigner_internal {
 
@@ -83,6 +85,22 @@ inline bool isObjectAncestorOf(QObject *ancestor, QObject *child)
     return false;
 }
 
+inline bool isCentralWidget(QDesignerFormWindowInterface *fw, QWidget *widget)
+{
+    if (! fw || ! widget)
+        return false;
+
+    if (widget == fw->mainContainer())
+        return true;
+
+    // ### generalize for other containers
+    if (QMainWindow *mw = qobject_cast<QMainWindow*>(fw->mainContainer())) {
+        return mw->centralWidget() == widget;
+    }
+
+    return false;
+}
+
 } // namespace Utils
 
 } // namespace qdesigner_internal
