@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
@@ -47,11 +47,17 @@ public:
     {
         QItemDelegate::paint(painter, option, index);
 
+        QPen savedPen = painter->pen();
+        QColor color = static_cast<QRgb>(QApplication::style()->styleHint(QStyle::SH_Table_GridLineColor, &option));
+        painter->setPen(QPen(color));
+
         painter->drawLine(option.rect.x(), option.rect.bottom(),
                             option.rect.right(), option.rect.bottom());
 
-        painter->drawLine(option.rect.right(), option.rect.y(),
-                            option.rect.right(), option.rect.bottom());
+        int right = (option.direction == Qt::LeftToRight) ? option.rect.right() : option.rect.left();
+        painter->drawLine(right, option.rect.y(), right, option.rect.bottom());
+
+        painter->setPen(savedPen);
     }
 
     virtual QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const
@@ -113,7 +119,11 @@ void TreeWidget::drawBranches(QPainter *painter, const QRect &rect, const QModel
 
         style()->drawPrimitive(QStyle::PE_IndicatorBranch, &option, painter, this);
     }
+    QPen savedPen = painter->pen();
+    QColor color = static_cast<QRgb>(QApplication::style()->styleHint(QStyle::SH_Table_GridLineColor, &option));
+    painter->setPen(QPen(color));
     painter->drawLine(rect.x(), rect.bottom(), rect.right(), rect.bottom());
+    painter->setPen(savedPen);
 }
 
 } // namespace qdesigner_internal
