@@ -34,6 +34,11 @@
 #include "q3listbox/q3listbox_plugin.h"
 #include "q3listview/q3listview_plugin.h"
 #include "q3textedit/q3textedit_plugin.h"
+#include "q3dateedit/q3dateedit_plugin.h"
+#include "q3timeedit/q3timeedit_plugin.h"
+#include "q3datetimeedit/q3datetimeedit_plugin.h"
+#include "q3progressbar/q3progressbar_plugin.h"
+#include "q3textbrowser/q3textbrowser_plugin.h"
 
 #include <QtDesigner/QtDesigner>
 #include <QtCore/qplugin.h>
@@ -67,6 +72,11 @@ Qt3SupportWidgets::Qt3SupportWidgets(QObject *parent)
     m_plugins.append(new Q3ListBoxPlugin(this));
     m_plugins.append(new Q3ListViewPlugin(this));
     m_plugins.append(new Q3TextEditPlugin(this));
+    m_plugins.append(new Q3DateEditPlugin(this));
+    m_plugins.append(new Q3TimeEditPlugin(this));
+    m_plugins.append(new Q3DateTimeEditPlugin(this));
+    m_plugins.append(new Q3ProgressBarPlugin(this));
+    m_plugins.append(new Q3TextBrowserPlugin(this));
 }
 
 QList<QDesignerCustomWidgetInterface*> Qt3SupportWidgets::customWidgets() const
