@@ -40,6 +40,8 @@
 #include <QtGui/qevent.h>
 #include <QtGui/qwidget.h>
 
+QT_BEGIN_HEADER
+
 namespace QTest
 {
     enum MouseAction { MousePress, MouseRelease, MouseClick, MouseDClick, MouseMove };
@@ -111,4 +113,6 @@ namespace QTest
 
 }
 
+QT_END_HEADER
+
 #endif // QTESTMOUSE_H
